// @bun
// src/explorer/index.ts
import { ViewPlugin as ViewPlugin3 } from "@codemirror/view";

// src/sidebar/index.ts
import { ViewPlugin, EditorView as EditorView2 } from "@codemirror/view";
import {
  StateField,
  StateEffect,
  Facet
} from "@codemirror/state";
import crelt from "crelt";

// src/sidebar/styles.ts
var styles = {
  sidebar: "cm-ext-sidebar",
  resizeHandle: "cm-ext-sidebar-resize",
  panelContainer: "cm-ext-sidebar-panel"
};
var defaultSidebarOptions = {
  overlay: true
};

// src/themes/sidebar.ts
import { EditorView } from "@codemirror/view";
var sidebarThemeVariables = {
  "--cm-ext-sidebar-bg": "#21222c",
  "--cm-ext-sidebar-border": "rgba(255, 255, 255, 0.2)",
  "--cm-ext-sidebar-resize-hover": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-sidebar-resize-active": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-sidebar-width": "250px",
  "--cm-ext-sidebar-resize-handle-width": "8px",
  "--cm-ext-sidebar-min-width": "150px",
  "--cm-ext-sidebar-max-width": "800px"
};
var sidebarTheme = {
  theme: EditorView.theme({
    "&": {
      height: "100vh",
      display: "flex !important",
      flexDirection: "row !important",
      position: "relative",
      ...Object.entries(sidebarThemeVariables).reduce((acc, [key, value]) => ({
        ...acc,
        [key]: value
      }), {})
    },
    ".cm-ext-sidebar": {
      height: "100%",
      width: "var(--cm-ext-sidebar-width)",
      display: "flex",
      flexDirection: "column",
      flexShrink: "0",
      transition: "transform 0.2s ease-in-out",
      transform: "translateX(0)",
      backgroundColor: "var(--cm-ext-sidebar-bg)",
      position: "relative",
      '&[data-overlay="true"]': {
        zIndex: "10",
        position: "absolute",
        top: "0",
        height: "100%",
        '&[data-dock="left"]': {
          left: "0"
        },
        '&[data-dock="right"]': {
          right: "0"
        }
      },
      '&[data-overlay="false"]': {
        position: "relative",
        zIndex: "1",
        overflow: "hidden",
        flexShrink: "0",
        '&[data-dock="left"]': {
          order: -1
        },
        '&[data-dock="right"]': {
          order: 1
        }
      },
      '&[data-visible="false"]': {
        transform: "translateX(100%)",
        display: "none"
      }
    },
    ".cm-ext-sidebar-panel": {
      height: "100%",
      overflow: "auto",
      backgroundColor: "var(--cm-ext-sidebar-bg)",
      '&[data-dock="left"]': {
        borderRight: "0.5px solid var(--cm-ext-sidebar-border)"
      },
      '&[data-dock="right"]': {
        borderLeft: "0.5px solid var(--cm-ext-sidebar-border)"
      }
    },
    ".cm-ext-sidebar-resize": {
      position: "absolute",
      top: "0",
      width: "var(--cm-ext-sidebar-resize-handle-width)",
      height: "100%",
      cursor: "col-resize",
      zIndex: "20",
      backgroundColor: "transparent",
      transition: "none"
    },
    ".cm-ext-sidebar-resize:hover": {
      backgroundColor: "var(--cm-ext-sidebar-resize-hover)",
      transitionProperty: "background-color",
      transitionDuration: "0.2s",
      transitionTimingFunction: "ease",
      transitionDelay: "150ms"
    },
    ".cm-ext-sidebar-resize:active": {
      backgroundColor: "var(--cm-ext-sidebar-resize-active)",
      transition: "none"
    },
    "&.cm-ext-sidebar-dragging": {
      cursor: "col-resize",
      userSelect: "none"
    },
    ".cm-scroller": {
      flex: "1 1 auto !important",
      minWidth: "0 !important",
      position: "relative",
      overflow: "auto"
    }
  })
};

// src/utils/logger.ts
import pino from "pino";
var isProduction = false;
var logger = pino({
  level: "debug",
  transport: !isProduction ? {
    target: "pino-pretty",
    options: {
      colorize: true,
      translateTime: "SYS:standard"
    }
  } : undefined
});
var logger_default = logger;

// src/sidebar/index.ts
var sidebarPanel = Facet.define({
  combine: (values) => values.flat()
});
var toggleSidebarEffect = StateEffect.define();
var updateSidebarOptionsEffect = StateEffect.define();
var setActivePanelEffect = StateEffect.define();
var sidebarStates = new Map;
var createSidebarState = (id, initialOptions) => {
  return StateField.define({
    create: () => ({
      visible: initialOptions.initiallyOpen ?? false,
      options: initialOptions,
      activePanelId: initialOptions.initiallyOpen && initialOptions.initialPanelId ? initialOptions.initialPanelId : null
    }),
    update(value, tr) {
      let newState = value;
      for (const e of tr.effects) {
        if (e.is(toggleSidebarEffect) && e.value.id === id) {
          newState = { ...newState, visible: e.value.visible };
        } else if (e.is(updateSidebarOptionsEffect) && e.value.id === id) {
          newState = {
            ...newState,
            options: { ...newState.options, ...e.value }
          };
        } else if (e.is(setActivePanelEffect) && e.value.id === id) {
          newState = {
            ...newState,
            activePanelId: e.value.panelId
          };
        }
      }
      return newState;
    }
  });
};
var toggleSidebarCommand = (view, sidebarId) => {
  const stateField = sidebarStates.get(sidebarId);
  if (!stateField) {
    debug("No state field for sidebar:", sidebarId);
    return false;
  }
  const state = view.state.field(stateField);
  const newVisible = !state.visible;
  debug("Toggling sidebar:", sidebarId, "from:", state.visible, "to:", newVisible);
  const effects = [
    toggleSidebarEffect.of({
      id: sidebarId,
      visible: newVisible
    })
  ];
  if (newVisible && !state.activePanelId) {
    const panels = view.state.facet(sidebarPanel);
    const panel = panels.find((p) => p.id === sidebarId);
    if (panel) {
      effects.push(setActivePanelEffect.of({
        id: sidebarId,
        panelId: panel.id
      }));
    }
  }
  view.dispatch({ effects });
  return true;
};
var debug = (...args) => logger_default.debug({ module: "Sidebar" }, args.join(" "));
var createSidebarPlugin = (id) => ViewPlugin.fromClass(class {
  dom;
  panelContainer;
  activePanel = null;
  resizeHandle;
  initialWidth = 0;
  initialX = 0;
  isDragging = false;
  constructor(view) {
    this.dom = crelt("div", {
      class: styles.sidebar,
      "data-sidebar-id": id
    });
    this.panelContainer = crelt("div", {
      class: styles.panelContainer
    });
    this.resizeHandle = crelt("div", {
      class: styles.resizeHandle
    });
    this.dom.appendChild(this.resizeHandle);
    this.dom.appendChild(this.panelContainer);
    const stateField = sidebarStates.get(id);
    const state = view.state.field(stateField);
    this.applySidebarStyles(state.options);
    this.updateVisibility(state.visible);
    view.dom.appendChild(this.dom);
    view.dom.style.position = "relative";
    this.renderActivePanel(view, state);
    this.setupResizeHandle();
  }
  update(update) {
    const stateField = sidebarStates.get(id);
    const state = update.state.field(stateField);
    const oldState = update.startState.field(stateField);
    if (state.visible !== oldState.visible) {
      debug("Visibility changed:", id, state.visible);
      this.applySidebarStyles(state.options);
      this.updateVisibility(state.visible);
      if (!state.visible) {
        update.view.focus();
      }
      const panels = update.state.facet(sidebarPanel);
      const activePanel = panels.find((p) => p.id === state.activePanelId);
      if (activePanel?.onVisibilityChange) {
        activePanel.onVisibilityChange(update.view, state.visible);
      }
    }
    if (state.options !== oldState.options) {
      debug("Options changed:", id, state.options);
      this.applySidebarStyles(state.options);
    }
    if (state.activePanelId !== oldState.activePanelId) {
      debug("Active panel changed:", id, state.activePanelId);
      this.renderActivePanel(update.view, state);
    }
  }
  destroy() {
    debug("Destroying sidebar plugin:", id);
    this.dom.remove();
  }
  updateVisibility(visible) {
    this.dom.setAttribute("data-visible", visible.toString());
  }
  setupResizeHandle() {
    const startDragging = (e) => {
      e.preventDefault();
      this.isDragging = true;
      this.initialX = e.clientX;
      this.initialWidth = this.dom.offsetWidth;
      document.addEventListener("mousemove", onDrag);
      document.addEventListener("mouseup", stopDragging);
      document.body.classList.add("cm-ext-sidebar-dragging");
    };
    const onDrag = (e) => {
      if (!this.isDragging)
        return;
      const stateField = sidebarStates.get(id);
      const editorElement = this.dom.closest(".cm-editor");
      if (!editorElement)
        return;
      const view = EditorView2.findFromDOM(editorElement);
      if (!view)
        return;
      const state = view.state.field(stateField);
      const delta = e.clientX - this.initialX;
      let newWidth = state.options.dock === "left" ? this.initialWidth + delta : this.initialWidth - delta;
      const minWidth = parseInt(sidebarThemeVariables["--cm-ext-sidebar-min-width"]);
      const maxWidth = parseInt(sidebarThemeVariables["--cm-ext-sidebar-max-width"]);
      newWidth = Math.max(minWidth, Math.min(maxWidth, newWidth));
      this.dom.style.setProperty("--cm-ext-sidebar-width", `${newWidth}px`);
    };
    const stopDragging = () => {
      if (!this.isDragging)
        return;
      this.isDragging = false;
      document.removeEventListener("mousemove", onDrag);
      document.removeEventListener("mouseup", stopDragging);
      document.body.classList.remove("cm-ext-sidebar-dragging");
      const stateField = sidebarStates.get(id);
      const editorElement = this.dom.closest(".cm-editor");
      if (!editorElement)
        return;
      const view = EditorView2.findFromDOM(editorElement);
      if (!view)
        return;
      view.dispatch({
        effects: updateSidebarOptionsEffect.of({
          ...view.state.field(stateField).options,
          width: this.dom.style.getPropertyValue("--cm-ext-sidebar-width")
        })
      });
    };
    this.resizeHandle.addEventListener("mousedown", startDragging);
  }
  applySidebarStyles(options) {
    const {
      width,
      backgroundColor,
      dock = "left",
      overlay = true
    } = options;
    this.dom.setAttribute("data-dock", dock);
    this.dom.setAttribute("data-overlay", overlay.toString());
    this.panelContainer.setAttribute("data-dock", dock);
    if (width) {
      this.dom.style.setProperty("--cm-ext-sidebar-width", width);
    }
    if (backgroundColor) {
      this.dom.style.setProperty("--cm-ext-sidebar-bg", backgroundColor);
    }
    if (dock === "left") {
      this.resizeHandle.style.left = "auto";
      this.resizeHandle.style.right = "-2px";
    } else {
      this.resizeHandle.style.left = "-2px";
      this.resizeHandle.style.right = "auto";
    }
    const editor = this.dom.closest(".cm-editor");
    if (editor) {
      editor.style.position = "relative";
    }
  }
  renderActivePanel(view, state) {
    if (this.activePanel) {
      this.activePanel.remove();
      this.activePanel = null;
    }
    if (state.activePanelId) {
      const panels = view.state.facet(sidebarPanel);
      const panel = panels.find((p) => p.id === state.activePanelId);
      if (panel) {
        this.activePanel = panel.create(view);
        this.panelContainer.appendChild(this.activePanel);
      }
    }
  }
});
function createSidebar(options) {
  const id = options.id;
  const stateField = createSidebarState(id, {
    ...defaultSidebarOptions,
    ...options
  });
  sidebarStates.set(id, stateField);
  return [stateField, createSidebarPlugin(id), sidebarTheme.theme];
}

// src/sidebar/keymap.ts
import { keymap } from "@codemirror/view";
var debug2 = (...args) => logger_default.debug("[Sidebar Keymap]", ...args);
function createSidebarBindings(sidebarId, key) {
  const bindings = [];
  debug2("Creating keymap bindings for sidebar:", sidebarId, key);
  if (typeof key === "string") {
    debug2("Adding universal key binding:", key);
    bindings.push({
      key,
      run: (view) => {
        debug2("Triggered universal key binding:", key);
        return toggleSidebarCommand(view, sidebarId);
      }
    });
  } else {
    if (key.mac) {
      debug2("Adding Mac key binding:", key.mac);
      bindings.push({
        mac: key.mac,
        run: (view) => {
          debug2("Triggered Mac key binding:", key.mac);
          return toggleSidebarCommand(view, sidebarId);
        }
      });
    }
    if (key.win) {
      debug2("Adding Windows key binding:", key.win);
      bindings.push({
        win: key.win,
        run: (view) => {
          debug2("Triggered Windows key binding:", key.win);
          return toggleSidebarCommand(view, sidebarId);
        }
      });
    }
  }
  return bindings;
}
function createSidebarKeymap(sidebarId, keymapConfig) {
  if (!keymapConfig) {
    debug2("No keymap config provided for sidebar:", sidebarId);
    return [];
  }
  debug2("Creating keymap extension for sidebar:", sidebarId, keymapConfig);
  return keymap.of(createSidebarBindings(sidebarId, keymapConfig));
}

// src/explorer/index.ts
import { Facet as Facet2 } from "@codemirror/state";

// src/themes/explorer.ts
import { EditorView as EditorView3 } from "@codemirror/view";
var explorerThemeVariables = {
  "--cm-ext-explorer-text": "rgb(197, 197, 199)",
  "--cm-ext-explorer-text-header": "#b1b1b3",
  "--cm-ext-explorer-border": "#2c313a",
  "--cm-ext-explorer-bg-hover": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-explorer-bg-selected": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-explorer-border-selected": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-explorer-header-font-size": "11px",
  "--cm-ext-explorer-header-font-weight": "800",
  "--cm-ext-explorer-header-letter-spacing": "0.5px",
  "--cm-ext-explorer-font-size": "12px",
  "--cm-ext-explorer-font-weight": "500"
};
var explorerTheme = {
  theme: EditorView3.theme({
    "&": {
      height: "100vh",
      display: "flex !important",
      flexDirection: "row !important",
      position: "relative",
      ...Object.entries(explorerThemeVariables).reduce((acc, [key, value]) => ({
        ...acc,
        [key]: value
      }), {})
    },
    ".cm-ext-explorer-content": {
      height: "100%",
      overflowY: "auto"
    },
    ".cm-ext-explorer-list": {
      listStyle: "none",
      padding: "0",
      margin: "0"
    },
    ".cm-ext-explorer-item": {
      border: "1px solid var(--cm-ext-explorer-border)",
      display: "flex",
      alignItems: "center",
      padding: "2.5px 8px",
      cursor: "pointer",
      transition: "background-color 0.2s",
      color: "var(--cm-ext-explorer-text)",
      fontSize: "var(--cm-ext-explorer-font-size)",
      fontWeight: "var(--cm-ext-explorer-font-weight)",
      "&:hover": {
        backgroundColor: "var(--cm-ext-explorer-bg-hover)"
      },
      "&.cm-ext-explorer-item-selected": {
        backgroundColor: "var(--cm-ext-explorer-bg-selected)",
        border: "1px solid var(--cm-ext-explorer-border-selected)"
      }
    },
    ".cm-ext-explorer-directory-item": {
      userSelect: "none",
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-caret": {
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      width: "20px",
      height: "12px",
      lineHeight: "12px",
      transform: "rotate(0deg) translateY(-1.5px)",
      textAlign: "center",
      userSelect: "none",
      fontSize: "18px",
      opacity: "0.6",
      transition: "transform 0.15s ease",
      flexShrink: 0,
      "&.cm-ext-explorer-caret-expanded": {
        transform: "rotate(90deg)"
      }
    },
    "h3.cm-ext-explorer-header": {
      userSelect: "none",
      textTransform: "uppercase",
      fontSize: "var(--cm-ext-explorer-header-font-size)",
      fontWeight: "var(--cm-ext-explorer-header-font-weight)",
      margin: "0",
      padding: "4px 8px 3px 10px",
      letterSpacing: "var(--cm-ext-explorer-header-letter-spacing)",
      color: "var(--cm-ext-explorer-text-header)",
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-header-title": {
      display: "inline-block"
    },
    ".cm-ext-explorer-header-copy": {
      background: "none",
      border: "none",
      padding: "4px",
      width: "20px",
      height: "20px",
      cursor: "pointer",
      color: "var(--cm-ext-explorer-text)",
      opacity: "0.5",
      transition: "all 0.2s",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      flexShrink: 0,
      "&:hover": {
        opacity: "0.8"
      },
      "&.success": {
        color: "#4ade80",
        opacity: "1"
      },
      "& svg": {
        width: "14px",
        height: "14px"
      }
    },
    ".cm-ext-explorer-directory span": {
      userSelect: "none",
      display: "flex",
      alignItems: "center",
      marginLeft: "16px"
    },
    ".cm-ext-explorer-file": {
      display: "flex",
      alignItems: "center",
      userSelect: "none"
    },
    ".cm-ext-explorer-file-item": {
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-icon": {
      width: "20px",
      height: "20px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      flexShrink: 0
    }
  })
};

// src/explorer/styles.ts
var styles2 = {
  explorerContent: "cm-ext-explorer-content",
  explorerList: "cm-ext-explorer-list",
  explorerItem: "cm-ext-explorer-item",
  explorerDirectory: "cm-ext-explorer-directory",
  explorerDirectoryItem: "cm-ext-explorer-directory-item",
  explorerFile: "cm-ext-explorer-file",
  explorerFileItem: "cm-ext-explorer-file-item",
  explorerItemSelected: "cm-ext-explorer-item-selected",
  directoryCaret: "cm-ext-explorer-caret",
  directoryCaretExpanded: "cm-ext-explorer-caret-expanded",
  explorerHeader: "cm-ext-explorer-header",
  explorerHeaderTitle: "cm-ext-explorer-header-title",
  explorerHeaderCopy: "cm-ext-explorer-header-copy",
  explorerIcon: "cm-ext-explorer-icon"
};
var defaultExplorerOptions = {
  overlay: false,
  width: "250px",
  dock: "left",
  backgroundColor: "#2c313a",
  initiallyOpen: false
};

// src/explorer/state.ts
import { StateField as StateField2, StateEffect as StateEffect2, Compartment } from "@codemirror/state";
import { ViewPlugin as ViewPlugin2 } from "@codemirror/view";
import { javascript } from "@codemirror/lang-javascript";
import { python } from "@codemirror/lang-python";
import { markdown } from "@codemirror/lang-markdown";
import { json } from "@codemirror/lang-json";
import crelt2 from "crelt";
var debug3 = (...args) => logger_default.debug({ module: "Explorer" }, args.join(" "));
var languageCompartment = new Compartment;
function getLanguageExtension(filename) {
  const ext = filename.toLowerCase().split(".").pop();
  switch (ext) {
    case "js":
    case "jsx":
    case "ts":
    case "tsx":
      return javascript({ typescript: ext.startsWith("ts") });
    case "py":
      return python();
    case "md":
    case "markdown":
      return markdown();
    case "json":
      return json();
    default:
      return null;
  }
}
var selectFileEffect = StateEffect2.define();
var updateFilesEffect = StateEffect2.define();
var toggleDirEffect = StateEffect2.define();
var setProjectNameEffect = StateEffect2.define();
var fileExplorerState = StateField2.define({
  create() {
    return {
      files: [],
      selectedFile: null,
      expandedDirs: new Set,
      projectName: undefined
    };
  },
  update(value, transaction) {
    for (const effect of transaction.effects) {
      if (effect.is(selectFileEffect)) {
        debug3("File selected:", effect.value);
        return { ...value, selectedFile: effect.value };
      } else if (effect.is(updateFilesEffect)) {
        debug3("Files updated:", effect.value.length, "files");
        return {
          ...value,
          files: effect.value,
          selectedFile: null
        };
      } else if (effect.is(toggleDirEffect)) {
        const newExpandedDirs = new Set(value.expandedDirs);
        if (newExpandedDirs.has(effect.value)) {
          newExpandedDirs.delete(effect.value);
        } else {
          newExpandedDirs.add(effect.value);
        }
        debug3("Directory toggled:", effect.value);
        return { ...value, expandedDirs: newExpandedDirs };
      } else if (effect.is(setProjectNameEffect)) {
        debug3("Project name set:", effect.value);
        return { ...value, projectName: effect.value };
      }
    }
    return value;
  }
});
function generateFileTree(files) {
  const tree = {};
  files.sort((a, b) => a.name.localeCompare(b.name)).forEach((file) => {
    const parts = file.name.split("/");
    let current = tree;
    parts.forEach((part) => {
      if (!(part in current)) {
        current[part] = {};
      }
      current = current[part];
    });
  });
  function renderTree(node, prefix = "") {
    const entries = Object.entries(node);
    const dirs = entries.filter(([, value]) => Object.keys(value).length > 0).sort(([a], [b]) => a.localeCompare(b));
    const files2 = entries.filter(([, value]) => Object.keys(value).length === 0).sort(([a], [b]) => a.localeCompare(b));
    const sortedEntries = [...dirs, ...files2];
    if (sortedEntries.length === 0)
      return "";
    let result = "";
    sortedEntries.forEach(([name, subNode], index) => {
      const isLastEntry = index === sortedEntries.length - 1;
      const connector = isLastEntry ? "\u2514\u2500\u2500" : "\u251C\u2500\u2500";
      const line = `${prefix}${connector} ${name}
`;
      const nextPrefix = prefix + (isLastEntry ? "    " : "\u2502   ");
      result += line;
      if (!isLastEntry || Object.keys(subNode).length > 0) {
        result += renderTree(subNode, nextPrefix);
      }
    });
    return result;
  }
  const treeContent = renderTree(tree).trimEnd();
  return `<file_map>
` + treeContent + `
</file_map>
`;
}
function generateFileContents(files) {
  const content = files.map((file) => {
    const ext = file.name.split(".").pop() || "";
    const trimmedContent = file.content.trim();
    return `File: ${file.name}
\`\`\`${ext}
${trimmedContent}
\`\`\``;
  }).join(`

`).trimEnd();
  return `<file_contents>
` + content + `
</file_contents>`;
}
var fileExplorerPanelSpec = {
  id: "file-explorer",
  create(view) {
    debug3("Creating file explorer panel");
    const dom = crelt2("div", { class: styles2.explorerContent });
    renderFileExplorer(dom, view);
    return dom;
  },
  update(view) {
    const dom = view.dom.querySelector(`.${styles2.explorerContent}`);
    if (dom) {
      renderFileExplorer(dom, view);
    }
  }
};
function renderFileExplorer(dom, view) {
  const explorerState = view.state.field(fileExplorerState);
  const headerContent = crelt2("span", { class: styles2.explorerHeaderTitle }, explorerState.projectName || "Files");
  const copyIcon = `<svg viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><rect x="9" y="9" width="13" height="13" rx="2" ry="2"></rect><path d="M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"></path></svg>`;
  const checkIcon = `<svg viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><polyline points="20 6 9 17 4 12"></polyline></svg>`;
  const copyButton = crelt2("button", {
    class: styles2.explorerHeaderCopy,
    title: "Copy Repository",
    onclick: (e) => {
      const btn = e.currentTarget;
      const fileTree2 = generateFileTree(explorerState.files);
      const fileContents = generateFileContents(explorerState.files);
      navigator.clipboard.writeText(fileTree2 + fileContents).then(() => {
        btn.innerHTML = checkIcon;
        btn.classList.add("success");
        setTimeout(() => {
          btn.innerHTML = copyIcon;
          btn.classList.remove("success");
        }, 3000);
      }).catch((err) => console.error("Failed to copy:", err));
    }
  });
  copyButton.innerHTML = copyIcon;
  const header = crelt2("h3", { class: styles2.explorerHeader }, headerContent, copyButton);
  const fileList = crelt2("ul", { class: styles2.explorerList });
  const fileTree = buildFileTree(explorerState.files);
  fileTree.forEach((node) => renderFileNode(node, 0, fileList, view, explorerState.selectedFile));
  dom.innerHTML = "";
  dom.appendChild(header);
  dom.appendChild(fileList);
}
function buildFileTree(files) {
  const root = [];
  const directories = {};
  const sortedFiles = [...files].sort((a, b) => a.name.localeCompare(b.name));
  sortedFiles.forEach((file) => {
    const parts = file.name.split("/");
    let currentPath = "";
    let currentChildren = root;
    parts.forEach((part, index) => {
      currentPath = currentPath ? `${currentPath}/${part}` : part;
      const isLastPart = index === parts.length - 1;
      if (isLastPart) {
        currentChildren.push({
          name: part,
          path: currentPath,
          content: file.content,
          isDirectory: false,
          children: []
        });
      } else {
        if (!directories[currentPath]) {
          const dirNode = {
            name: part,
            path: currentPath,
            isDirectory: true,
            children: []
          };
          directories[currentPath] = dirNode;
          currentChildren.push(dirNode);
        }
        currentChildren = directories[currentPath].children;
      }
    });
  });
  return sortNodes(root);
}
function sortNodes(nodes) {
  return nodes.sort((a, b) => {
    if (a.isDirectory !== b.isDirectory) {
      return a.isDirectory ? -1 : 1;
    }
    return a.name.localeCompare(b.name);
  }).map((node) => {
    if (node.isDirectory) {
      node.children = sortNodes(node.children);
    }
    return node;
  });
}
function renderFileNode(node, level, container, view, selectedFile) {
  const indentation = 5 + level * 8;
  const explorerState = view.state.field(fileExplorerState);
  if (node.isDirectory) {
    const isExpanded = explorerState.expandedDirs.has(node.path);
    const caretSpan = crelt2("span", {
      class: `${styles2.directoryCaret}${isExpanded ? ` ${styles2.directoryCaretExpanded}` : ""}`
    }, "\u203A");
    const dirSpan = crelt2("span", { class: styles2.explorerDirectory }, node.name);
    const dirItem = crelt2("li", {
      class: `${styles2.explorerItem} ${styles2.explorerDirectoryItem}`,
      style: `padding-left: ${indentation}px`,
      onclick: () => {
        view.dispatch({
          effects: toggleDirEffect.of(node.path)
        });
      }
    }, caretSpan, dirSpan);
    container.appendChild(dirItem);
    if (isExpanded) {
      node.children.forEach((child) => renderFileNode(child, level + 1, container, view, selectedFile));
    }
  } else {
    const iconSpan = crelt2("span", { class: styles2.explorerIcon }, "");
    const fileSpan = crelt2("span", { class: styles2.explorerFile }, node.name);
    const fileItem = crelt2("li", {
      "data-file": node.path,
      class: `${styles2.explorerItem} ${styles2.explorerFileItem}${node.path === selectedFile ? ` ${styles2.explorerItemSelected}` : ""}`,
      style: `padding-left: ${indentation}px`,
      onclick: () => {
        if (node.content) {
          debug3("Loading file:", node.path);
          const langExtension = getLanguageExtension(node.path);
          view.dispatch({
            effects: [
              selectFileEffect.of(node.path),
              ...langExtension ? [
                languageCompartment.reconfigure(langExtension)
              ] : []
            ],
            changes: {
              from: 0,
              to: view.state.doc.length,
              insert: node.content
            }
          });
        }
      }
    }, iconSpan, fileSpan);
    container.appendChild(fileItem);
  }
}
var fileExplorerPlugin = ViewPlugin2.fromClass(class {
  update(update) {
    if (update.state.field(fileExplorerState) !== update.startState.field(fileExplorerState)) {
      debug3("Explorer state changed, updating panel");
      const dom = update.view.dom.querySelector(`.${styles2.explorerContent}`);
      if (dom) {
        renderFileExplorer(dom, update.view);
      }
    }
  }
});
// src/explorer/commands.ts
function toggleExplorer(view) {
  return toggleSidebarCommand(view, "file-explorer");
}

// src/explorer/index.ts
var debug4 = (...args) => logger_default.debug("[Explorer]", ...args);
var explorerKeymap = Facet2.define({
  combine: (values) => values[0]
});
function setupPanelKeyboardShortcuts(dom, view, keyConfig) {
  const isMac = /Mac/.test(navigator.platform);
  const keys = typeof keyConfig === "string" ? { mac: keyConfig, win: keyConfig } : keyConfig;
  const targetKey = (isMac ? keys.mac : keys.win)?.toLowerCase();
  if (!targetKey)
    return;
  debug4("Setting up panel keyboard shortcuts:", { isMac, targetKey });
  dom.addEventListener("keydown", (event) => {
    const modKey = isMac ? event.metaKey : event.ctrlKey;
    if (!modKey)
      return;
    const pressedKey = `${isMac ? "cmd" : "ctrl"}-${event.key.toLowerCase()}`;
    debug4("Key pressed in panel:", pressedKey);
    if (pressedKey === targetKey) {
      event.preventDefault();
      event.stopPropagation();
      debug4("Executing panel keyboard shortcut:", targetKey);
      toggleSidebarCommand(view, "file-explorer");
    }
  });
}
function createFileSelectPlugin(onFileSelect) {
  return ViewPlugin3.fromClass(class {
    update(update) {
      if (!onFileSelect)
        return;
      for (const effect of update.transactions.flatMap((tr) => tr.effects)) {
        if (effect.is(selectFileEffect)) {
          onFileSelect(effect.value, update.view);
        }
      }
    }
  });
}
var explorerPanelSpec = {
  ...fileExplorerPanelSpec,
  create(view) {
    const dom = fileExplorerPanelSpec.create(view);
    const keymapOpt = view.state.facet(explorerKeymap);
    if (keymapOpt) {
      setupPanelKeyboardShortcuts(dom, view, keymapOpt);
    }
    return dom;
  }
};
function explorer(options = {}) {
  const {
    dock = defaultExplorerOptions.dock,
    width = defaultExplorerOptions.width,
    overlay = defaultExplorerOptions.overlay,
    backgroundColor = defaultExplorerOptions.backgroundColor,
    keymap: keymapOpt,
    initiallyOpen = defaultExplorerOptions.initiallyOpen,
    onFileSelect,
    theme = {}
  } = options;
  const sidebarOptions = {
    id: "file-explorer",
    dock,
    width,
    overlay,
    backgroundColor,
    initiallyOpen,
    initialPanelId: "file-explorer",
    theme
  };
  return [
    ...createSidebar(sidebarOptions),
    fileExplorerState,
    fileExplorerPlugin,
    sidebarPanel.of(explorerPanelSpec),
    languageCompartment.of([]),
    onFileSelect ? createFileSelectPlugin(onFileSelect) : [],
    keymapOpt ? explorerKeymap.of(keymapOpt) : [],
    createSidebarKeymap("file-explorer", keymapOpt),
    explorerTheme.theme
  ];
}
export {
  updateFilesEffect,
  toggleExplorer,
  setProjectNameEffect,
  selectFileEffect,
  explorerThemeVariables,
  explorer
};
