// @bun
// src/explorer/index.ts
import { ViewPlugin as ViewPlugin3 } from "@codemirror/view";

// src/sidebar/index.ts
import { ViewPlugin, EditorView as EditorView2 } from "@codemirror/view";
import {
  StateField,
  StateEffect,
  Facet
} from "@codemirror/state";
import crelt from "crelt";

// src/sidebar/styles.ts
var styles = {
  sidebar: "cm-ext-sidebar",
  resizeHandle: "cm-ext-sidebar-resize",
  panelContainer: "cm-ext-sidebar-panel"
};
var defaultSidebarOptions = {
  overlay: true
};

// src/themes/sidebar.ts
import { EditorView } from "@codemirror/view";
var sidebarThemeVariables = {
  "--cm-ext-sidebar-bg": "#21222c",
  "--cm-ext-sidebar-border": "rgba(255, 255, 255, 0.2)",
  "--cm-ext-sidebar-resize-hover": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-sidebar-resize-active": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-sidebar-width": "250px",
  "--cm-ext-sidebar-resize-handle-width": "8px",
  "--cm-ext-sidebar-min-width": "150px",
  "--cm-ext-sidebar-max-width": "800px"
};
var sidebarTheme = {
  theme: EditorView.theme({
    "&": {
      height: "100vh",
      display: "flex !important",
      flexDirection: "row !important",
      position: "relative",
      ...Object.entries(sidebarThemeVariables).reduce((acc, [key, value]) => ({
        ...acc,
        [key]: value
      }), {})
    },
    ".cm-ext-sidebar": {
      height: "100%",
      width: "var(--cm-ext-sidebar-width)",
      display: "flex",
      flexDirection: "column",
      flexShrink: "0",
      transition: "transform 0.2s ease-in-out",
      transform: "translateX(0)",
      backgroundColor: "var(--cm-ext-sidebar-bg)",
      position: "relative",
      '&[data-overlay="true"]': {
        zIndex: "10",
        position: "absolute",
        top: "0",
        height: "100%",
        '&[data-dock="left"]': {
          left: "0"
        },
        '&[data-dock="right"]': {
          right: "0"
        }
      },
      '&[data-overlay="false"]': {
        position: "relative",
        zIndex: "1",
        overflow: "hidden",
        flexShrink: "0",
        '&[data-dock="left"]': {
          order: -1
        },
        '&[data-dock="right"]': {
          order: 1
        }
      },
      '&[data-visible="false"]': {
        transform: "translateX(100%)",
        display: "none"
      }
    },
    ".cm-ext-sidebar-panel": {
      height: "100%",
      overflow: "auto",
      backgroundColor: "var(--cm-ext-sidebar-bg)",
      '&[data-dock="left"]': {
        borderRight: "0.5px solid var(--cm-ext-sidebar-border)"
      },
      '&[data-dock="right"]': {
        borderLeft: "0.5px solid var(--cm-ext-sidebar-border)"
      }
    },
    ".cm-ext-sidebar-resize": {
      position: "absolute",
      top: "0",
      width: "var(--cm-ext-sidebar-resize-handle-width)",
      height: "100%",
      cursor: "col-resize",
      zIndex: "20",
      backgroundColor: "transparent",
      transition: "none"
    },
    ".cm-ext-sidebar-resize:hover": {
      backgroundColor: "var(--cm-ext-sidebar-resize-hover)",
      transitionProperty: "background-color",
      transitionDuration: "0.2s",
      transitionTimingFunction: "ease",
      transitionDelay: "150ms"
    },
    ".cm-ext-sidebar-resize:active": {
      backgroundColor: "var(--cm-ext-sidebar-resize-active)",
      transition: "none"
    },
    "&.cm-ext-sidebar-dragging": {
      cursor: "col-resize",
      userSelect: "none"
    },
    ".cm-scroller": {
      flex: "1 1 auto !important",
      minWidth: "0 !important",
      position: "relative",
      overflow: "auto"
    }
  })
};

// src/utils/logger.ts
import pino from "pino";
var isProduction = false;
var logger = pino({
  level: "debug",
  transport: !isProduction ? {
    target: "pino-pretty",
    options: {
      colorize: true,
      translateTime: "SYS:standard"
    }
  } : undefined
});
var logger_default = logger;

// src/sidebar/index.ts
var sidebarPanel = Facet.define({
  combine: (values) => values.flat()
});
var toggleSidebarEffect = StateEffect.define();
var updateSidebarOptionsEffect = StateEffect.define();
var setActivePanelEffect = StateEffect.define();
var sidebarStates = new Map;
var createSidebarState = (id, initialOptions) => {
  return StateField.define({
    create: () => ({
      visible: initialOptions.initiallyOpen ?? false,
      options: initialOptions,
      activePanelId: initialOptions.initiallyOpen && initialOptions.initialPanelId ? initialOptions.initialPanelId : null
    }),
    update(value, tr) {
      let newState = value;
      for (const e of tr.effects) {
        if (e.is(toggleSidebarEffect) && e.value.id === id) {
          newState = { ...newState, visible: e.value.visible };
        } else if (e.is(updateSidebarOptionsEffect) && e.value.id === id) {
          newState = {
            ...newState,
            options: { ...newState.options, ...e.value }
          };
        } else if (e.is(setActivePanelEffect) && e.value.id === id) {
          newState = {
            ...newState,
            activePanelId: e.value.panelId
          };
        }
      }
      return newState;
    }
  });
};
var toggleSidebarCommand = (view, sidebarId) => {
  const stateField = sidebarStates.get(sidebarId);
  if (!stateField) {
    debug("No state field for sidebar:", sidebarId);
    return false;
  }
  const state = view.state.field(stateField);
  const newVisible = !state.visible;
  debug("Toggling sidebar:", sidebarId, "from:", state.visible, "to:", newVisible);
  const effects = [
    toggleSidebarEffect.of({
      id: sidebarId,
      visible: newVisible
    })
  ];
  if (newVisible && !state.activePanelId) {
    const panels = view.state.facet(sidebarPanel);
    const panel = panels.find((p) => p.id === sidebarId);
    if (panel) {
      effects.push(setActivePanelEffect.of({
        id: sidebarId,
        panelId: panel.id
      }));
    }
  }
  view.dispatch({ effects });
  return true;
};
var debug = (...args) => logger_default.debug({ module: "Sidebar" }, args.join(" "));
var createSidebarPlugin = (id) => ViewPlugin.fromClass(class {
  dom;
  panelContainer;
  activePanel = null;
  resizeHandle;
  initialWidth = 0;
  initialX = 0;
  isDragging = false;
  constructor(view) {
    this.dom = crelt("div", {
      class: styles.sidebar,
      "data-sidebar-id": id
    });
    this.panelContainer = crelt("div", {
      class: styles.panelContainer
    });
    this.resizeHandle = crelt("div", {
      class: styles.resizeHandle
    });
    this.dom.appendChild(this.resizeHandle);
    this.dom.appendChild(this.panelContainer);
    const stateField = sidebarStates.get(id);
    const state = view.state.field(stateField);
    this.applySidebarStyles(state.options);
    this.updateVisibility(state.visible);
    view.dom.appendChild(this.dom);
    view.dom.style.position = "relative";
    this.renderActivePanel(view, state);
    this.setupResizeHandle();
  }
  update(update) {
    const stateField = sidebarStates.get(id);
    const state = update.state.field(stateField);
    const oldState = update.startState.field(stateField);
    if (state.visible !== oldState.visible) {
      debug("Visibility changed:", id, state.visible);
      this.applySidebarStyles(state.options);
      this.updateVisibility(state.visible);
      if (!state.visible) {
        update.view.focus();
      }
      const panels = update.state.facet(sidebarPanel);
      const activePanel = panels.find((p) => p.id === state.activePanelId);
      if (activePanel?.onVisibilityChange) {
        activePanel.onVisibilityChange(update.view, state.visible);
      }
    }
    if (state.options !== oldState.options) {
      debug("Options changed:", id, state.options);
      this.applySidebarStyles(state.options);
    }
    if (state.activePanelId !== oldState.activePanelId) {
      debug("Active panel changed:", id, state.activePanelId);
      this.renderActivePanel(update.view, state);
    }
  }
  destroy() {
    debug("Destroying sidebar plugin:", id);
    this.dom.remove();
  }
  updateVisibility(visible) {
    this.dom.setAttribute("data-visible", visible.toString());
  }
  setupResizeHandle() {
    const startDragging = (e) => {
      e.preventDefault();
      this.isDragging = true;
      this.initialX = e.clientX;
      this.initialWidth = this.dom.offsetWidth;
      document.addEventListener("mousemove", onDrag);
      document.addEventListener("mouseup", stopDragging);
      document.body.classList.add("cm-ext-sidebar-dragging");
    };
    const onDrag = (e) => {
      if (!this.isDragging)
        return;
      const stateField = sidebarStates.get(id);
      const editorElement = this.dom.closest(".cm-editor");
      if (!editorElement)
        return;
      const view = EditorView2.findFromDOM(editorElement);
      if (!view)
        return;
      const state = view.state.field(stateField);
      const delta = e.clientX - this.initialX;
      let newWidth = state.options.dock === "left" ? this.initialWidth + delta : this.initialWidth - delta;
      const minWidth = parseInt(sidebarThemeVariables["--cm-ext-sidebar-min-width"]);
      const maxWidth = parseInt(sidebarThemeVariables["--cm-ext-sidebar-max-width"]);
      newWidth = Math.max(minWidth, Math.min(maxWidth, newWidth));
      this.dom.style.setProperty("--cm-ext-sidebar-width", `${newWidth}px`);
    };
    const stopDragging = () => {
      if (!this.isDragging)
        return;
      this.isDragging = false;
      document.removeEventListener("mousemove", onDrag);
      document.removeEventListener("mouseup", stopDragging);
      document.body.classList.remove("cm-ext-sidebar-dragging");
      const stateField = sidebarStates.get(id);
      const editorElement = this.dom.closest(".cm-editor");
      if (!editorElement)
        return;
      const view = EditorView2.findFromDOM(editorElement);
      if (!view)
        return;
      view.dispatch({
        effects: updateSidebarOptionsEffect.of({
          ...view.state.field(stateField).options,
          width: this.dom.style.getPropertyValue("--cm-ext-sidebar-width")
        })
      });
    };
    this.resizeHandle.addEventListener("mousedown", startDragging);
  }
  applySidebarStyles(options) {
    const {
      width,
      backgroundColor,
      dock = "left",
      overlay = true
    } = options;
    this.dom.setAttribute("data-dock", dock);
    this.dom.setAttribute("data-overlay", overlay.toString());
    this.panelContainer.setAttribute("data-dock", dock);
    if (width) {
      this.dom.style.setProperty("--cm-ext-sidebar-width", width);
    }
    if (backgroundColor) {
      this.dom.style.setProperty("--cm-ext-sidebar-bg", backgroundColor);
    }
    if (dock === "left") {
      this.resizeHandle.style.left = "auto";
      this.resizeHandle.style.right = "-2px";
    } else {
      this.resizeHandle.style.left = "-2px";
      this.resizeHandle.style.right = "auto";
    }
    const editor = this.dom.closest(".cm-editor");
    if (editor) {
      editor.style.position = "relative";
    }
  }
  renderActivePanel(view, state) {
    if (this.activePanel) {
      this.activePanel.remove();
      this.activePanel = null;
    }
    if (state.activePanelId) {
      const panels = view.state.facet(sidebarPanel);
      const panel = panels.find((p) => p.id === state.activePanelId);
      if (panel) {
        this.activePanel = panel.create(view);
        this.panelContainer.appendChild(this.activePanel);
      }
    }
  }
});
function createSidebar(options) {
  const id = options.id;
  const stateField = createSidebarState(id, {
    ...defaultSidebarOptions,
    ...options
  });
  sidebarStates.set(id, stateField);
  return [stateField, createSidebarPlugin(id), sidebarTheme.theme];
}

// src/sidebar/keymap.ts
import { keymap } from "@codemirror/view";
var debug2 = (...args) => logger_default.debug("[Sidebar Keymap]", ...args);
function createSidebarBindings(sidebarId, key) {
  const bindings = [];
  debug2("Creating keymap bindings for sidebar:", sidebarId, key);
  if (typeof key === "string") {
    debug2("Adding universal key binding:", key);
    bindings.push({
      key,
      run: (view) => {
        debug2("Triggered universal key binding:", key);
        return toggleSidebarCommand(view, sidebarId);
      }
    });
  } else {
    if (key.mac) {
      debug2("Adding Mac key binding:", key.mac);
      bindings.push({
        mac: key.mac,
        run: (view) => {
          debug2("Triggered Mac key binding:", key.mac);
          return toggleSidebarCommand(view, sidebarId);
        }
      });
    }
    if (key.win) {
      debug2("Adding Windows key binding:", key.win);
      bindings.push({
        win: key.win,
        run: (view) => {
          debug2("Triggered Windows key binding:", key.win);
          return toggleSidebarCommand(view, sidebarId);
        }
      });
    }
  }
  return bindings;
}
function createSidebarKeymap(sidebarId, keymapConfig) {
  if (!keymapConfig) {
    debug2("No keymap config provided for sidebar:", sidebarId);
    return [];
  }
  debug2("Creating keymap extension for sidebar:", sidebarId, keymapConfig);
  return keymap.of(createSidebarBindings(sidebarId, keymapConfig));
}

// src/explorer/index.ts
import { Facet as Facet2 } from "@codemirror/state";

// src/themes/explorer.ts
import { EditorView as EditorView3 } from "@codemirror/view";
var explorerThemeVariables = {
  "--cm-ext-explorer-text": "rgb(197, 197, 199)",
  "--cm-ext-explorer-text-header": "#b1b1b3",
  "--cm-ext-explorer-border": "#2c313a",
  "--cm-ext-explorer-bg-hover": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-explorer-bg-selected": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-explorer-border-selected": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-explorer-header-font-size": "11px",
  "--cm-ext-explorer-header-font-weight": "800",
  "--cm-ext-explorer-header-letter-spacing": "0.5px",
  "--cm-ext-explorer-font-size": "12px",
  "--cm-ext-explorer-font-weight": "500"
};
var explorerTheme = {
  theme: EditorView3.theme({
    "&": {
      height: "100vh",
      display: "flex !important",
      flexDirection: "row !important",
      position: "relative",
      ...Object.entries(explorerThemeVariables).reduce((acc, [key, value]) => ({
        ...acc,
        [key]: value
      }), {})
    },
    ".cm-ext-explorer-content": {
      height: "100%",
      overflowY: "auto"
    },
    ".cm-ext-explorer-list": {
      listStyle: "none",
      padding: "0",
      margin: "0"
    },
    ".cm-ext-explorer-item": {
      border: "1px solid var(--cm-ext-explorer-border)",
      display: "flex",
      alignItems: "center",
      padding: "2.5px 8px",
      cursor: "pointer",
      transition: "background-color 0.2s",
      color: "var(--cm-ext-explorer-text)",
      fontSize: "var(--cm-ext-explorer-font-size)",
      fontWeight: "var(--cm-ext-explorer-font-weight)",
      "&:hover": {
        backgroundColor: "var(--cm-ext-explorer-bg-hover)"
      },
      "&.cm-ext-explorer-item-selected": {
        backgroundColor: "var(--cm-ext-explorer-bg-selected)",
        border: "1px solid var(--cm-ext-explorer-border-selected)"
      }
    },
    ".cm-ext-explorer-directory-item": {
      userSelect: "none",
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-caret": {
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      width: "20px",
      height: "12px",
      lineHeight: "12px",
      transform: "rotate(0deg) translateY(-1.5px)",
      textAlign: "center",
      userSelect: "none",
      fontSize: "18px",
      opacity: "0.6",
      transition: "transform 0.15s ease",
      flexShrink: 0,
      "&.cm-ext-explorer-caret-expanded": {
        transform: "rotate(90deg)"
      }
    },
    "h3.cm-ext-explorer-header": {
      userSelect: "none",
      textTransform: "uppercase",
      fontSize: "var(--cm-ext-explorer-header-font-size)",
      fontWeight: "var(--cm-ext-explorer-header-font-weight)",
      margin: "0",
      padding: "4px 8px 3px 10px",
      letterSpacing: "var(--cm-ext-explorer-header-letter-spacing)",
      color: "var(--cm-ext-explorer-text-header)",
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-header-title": {
      display: "inline-block"
    },
    ".cm-ext-explorer-header-copy": {
      background: "none",
      border: "none",
      padding: "4px",
      width: "20px",
      height: "20px",
      cursor: "pointer",
      color: "var(--cm-ext-explorer-text)",
      opacity: "0.5",
      transition: "all 0.2s",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      flexShrink: 0,
      "&:hover": {
        opacity: "0.8"
      },
      "&.success": {
        color: "#4ade80",
        opacity: "1"
      },
      "& svg": {
        width: "14px",
        height: "14px"
      }
    },
    ".cm-ext-explorer-directory span": {
      userSelect: "none",
      display: "flex",
      alignItems: "center",
      marginLeft: "16px"
    },
    ".cm-ext-explorer-file": {
      display: "flex",
      alignItems: "center",
      userSelect: "none"
    },
    ".cm-ext-explorer-file-item": {
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-explorer-icon": {
      width: "20px",
      height: "20px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      flexShrink: 0
    }
  })
};

// src/explorer/styles.ts
var styles2 = {
  explorerContent: "cm-ext-explorer-content",
  explorerList: "cm-ext-explorer-list",
  explorerItem: "cm-ext-explorer-item",
  explorerDirectory: "cm-ext-explorer-directory",
  explorerDirectoryItem: "cm-ext-explorer-directory-item",
  explorerFile: "cm-ext-explorer-file",
  explorerFileItem: "cm-ext-explorer-file-item",
  explorerItemSelected: "cm-ext-explorer-item-selected",
  directoryCaret: "cm-ext-explorer-caret",
  directoryCaretExpanded: "cm-ext-explorer-caret-expanded",
  explorerHeader: "cm-ext-explorer-header",
  explorerHeaderTitle: "cm-ext-explorer-header-title",
  explorerHeaderCopy: "cm-ext-explorer-header-copy",
  explorerIcon: "cm-ext-explorer-icon"
};
var defaultExplorerOptions = {
  overlay: false,
  width: "250px",
  dock: "left",
  backgroundColor: "#2c313a",
  initiallyOpen: false
};

// src/explorer/state.ts
import { StateField as StateField2, StateEffect as StateEffect2, Compartment } from "@codemirror/state";
import { ViewPlugin as ViewPlugin2 } from "@codemirror/view";
import { javascript } from "@codemirror/lang-javascript";
import { python } from "@codemirror/lang-python";
import { markdown } from "@codemirror/lang-markdown";
import { json } from "@codemirror/lang-json";
import crelt2 from "crelt";
var debug3 = (...args) => logger_default.debug({ module: "Explorer" }, args.join(" "));
var languageCompartment = new Compartment;
function getLanguageExtension(filename) {
  const ext = filename.toLowerCase().split(".").pop();
  switch (ext) {
    case "js":
    case "jsx":
    case "ts":
    case "tsx":
      return javascript({ typescript: ext.startsWith("ts") });
    case "py":
      return python();
    case "md":
    case "markdown":
      return markdown();
    case "json":
      return json();
    default:
      return null;
  }
}
var selectFileEffect = StateEffect2.define();
var updateFilesEffect = StateEffect2.define();
var toggleDirEffect = StateEffect2.define();
var setProjectNameEffect = StateEffect2.define();
var fileExplorerState = StateField2.define({
  create() {
    return {
      files: [],
      selectedFile: null,
      expandedDirs: new Set,
      projectName: undefined
    };
  },
  update(value, transaction) {
    for (const effect of transaction.effects) {
      if (effect.is(selectFileEffect)) {
        debug3("File selected:", effect.value);
        return { ...value, selectedFile: effect.value };
      } else if (effect.is(updateFilesEffect)) {
        debug3("Files updated:", effect.value.length, "files");
        return {
          ...value,
          files: effect.value,
          selectedFile: null
        };
      } else if (effect.is(toggleDirEffect)) {
        const newExpandedDirs = new Set(value.expandedDirs);
        if (newExpandedDirs.has(effect.value)) {
          newExpandedDirs.delete(effect.value);
        } else {
          newExpandedDirs.add(effect.value);
        }
        debug3("Directory toggled:", effect.value);
        return { ...value, expandedDirs: newExpandedDirs };
      } else if (effect.is(setProjectNameEffect)) {
        debug3("Project name set:", effect.value);
        return { ...value, projectName: effect.value };
      }
    }
    return value;
  }
});
function generateFileTree(files) {
  const tree = {};
  files.sort((a, b) => a.name.localeCompare(b.name)).forEach((file) => {
    const parts = file.name.split("/");
    let current = tree;
    parts.forEach((part) => {
      if (!(part in current)) {
        current[part] = {};
      }
      current = current[part];
    });
  });
  function renderTree(node, prefix = "") {
    const entries = Object.entries(node);
    const dirs = entries.filter(([, value]) => Object.keys(value).length > 0).sort(([a], [b]) => a.localeCompare(b));
    const files2 = entries.filter(([, value]) => Object.keys(value).length === 0).sort(([a], [b]) => a.localeCompare(b));
    const sortedEntries = [...dirs, ...files2];
    if (sortedEntries.length === 0)
      return "";
    let result = "";
    sortedEntries.forEach(([name, subNode], index) => {
      const isLastEntry = index === sortedEntries.length - 1;
      const connector = isLastEntry ? "\u2514\u2500\u2500" : "\u251C\u2500\u2500";
      const line = `${prefix}${connector} ${name}
`;
      const nextPrefix = prefix + (isLastEntry ? "    " : "\u2502   ");
      result += line;
      if (!isLastEntry || Object.keys(subNode).length > 0) {
        result += renderTree(subNode, nextPrefix);
      }
    });
    return result;
  }
  const treeContent = renderTree(tree).trimEnd();
  return `<file_map>
` + treeContent + `
</file_map>
`;
}
function generateFileContents(files) {
  const content = files.map((file) => {
    const ext = file.name.split(".").pop() || "";
    const trimmedContent = file.content.trim();
    return `File: ${file.name}
\`\`\`${ext}
${trimmedContent}
\`\`\``;
  }).join(`

`).trimEnd();
  return `<file_contents>
` + content + `
</file_contents>`;
}
var fileExplorerPanelSpec = {
  id: "file-explorer",
  create(view) {
    debug3("Creating file explorer panel");
    const dom = crelt2("div", { class: styles2.explorerContent });
    renderFileExplorer(dom, view);
    return dom;
  },
  update(view) {
    const dom = view.dom.querySelector(`.${styles2.explorerContent}`);
    if (dom) {
      renderFileExplorer(dom, view);
    }
  }
};
function renderFileExplorer(dom, view) {
  const explorerState = view.state.field(fileExplorerState);
  const headerContent = crelt2("span", { class: styles2.explorerHeaderTitle }, explorerState.projectName || "Files");
  const copyIcon = `<svg viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><rect x="9" y="9" width="13" height="13" rx="2" ry="2"></rect><path d="M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"></path></svg>`;
  const checkIcon = `<svg viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><polyline points="20 6 9 17 4 12"></polyline></svg>`;
  const copyButton = crelt2("button", {
    class: styles2.explorerHeaderCopy,
    title: "Copy Repository",
    onclick: (e) => {
      const btn = e.currentTarget;
      const fileTree2 = generateFileTree(explorerState.files);
      const fileContents = generateFileContents(explorerState.files);
      navigator.clipboard.writeText(fileTree2 + fileContents).then(() => {
        btn.innerHTML = checkIcon;
        btn.classList.add("success");
        setTimeout(() => {
          btn.innerHTML = copyIcon;
          btn.classList.remove("success");
        }, 3000);
      }).catch((err) => console.error("Failed to copy:", err));
    }
  });
  copyButton.innerHTML = copyIcon;
  const header = crelt2("h3", { class: styles2.explorerHeader }, headerContent, copyButton);
  const fileList = crelt2("ul", { class: styles2.explorerList });
  const fileTree = buildFileTree(explorerState.files);
  fileTree.forEach((node) => renderFileNode(node, 0, fileList, view, explorerState.selectedFile));
  dom.innerHTML = "";
  dom.appendChild(header);
  dom.appendChild(fileList);
}
function buildFileTree(files) {
  const root = [];
  const directories = {};
  const sortedFiles = [...files].sort((a, b) => a.name.localeCompare(b.name));
  sortedFiles.forEach((file) => {
    const parts = file.name.split("/");
    let currentPath = "";
    let currentChildren = root;
    parts.forEach((part, index) => {
      currentPath = currentPath ? `${currentPath}/${part}` : part;
      const isLastPart = index === parts.length - 1;
      if (isLastPart) {
        currentChildren.push({
          name: part,
          path: currentPath,
          content: file.content,
          isDirectory: false,
          children: []
        });
      } else {
        if (!directories[currentPath]) {
          const dirNode = {
            name: part,
            path: currentPath,
            isDirectory: true,
            children: []
          };
          directories[currentPath] = dirNode;
          currentChildren.push(dirNode);
        }
        currentChildren = directories[currentPath].children;
      }
    });
  });
  return sortNodes(root);
}
function sortNodes(nodes) {
  return nodes.sort((a, b) => {
    if (a.isDirectory !== b.isDirectory) {
      return a.isDirectory ? -1 : 1;
    }
    return a.name.localeCompare(b.name);
  }).map((node) => {
    if (node.isDirectory) {
      node.children = sortNodes(node.children);
    }
    return node;
  });
}
function renderFileNode(node, level, container, view, selectedFile) {
  const indentation = 5 + level * 8;
  const explorerState = view.state.field(fileExplorerState);
  if (node.isDirectory) {
    const isExpanded = explorerState.expandedDirs.has(node.path);
    const caretSpan = crelt2("span", {
      class: `${styles2.directoryCaret}${isExpanded ? ` ${styles2.directoryCaretExpanded}` : ""}`
    }, "\u203A");
    const dirSpan = crelt2("span", { class: styles2.explorerDirectory }, node.name);
    const dirItem = crelt2("li", {
      class: `${styles2.explorerItem} ${styles2.explorerDirectoryItem}`,
      style: `padding-left: ${indentation}px`,
      onclick: () => {
        view.dispatch({
          effects: toggleDirEffect.of(node.path)
        });
      }
    }, caretSpan, dirSpan);
    container.appendChild(dirItem);
    if (isExpanded) {
      node.children.forEach((child) => renderFileNode(child, level + 1, container, view, selectedFile));
    }
  } else {
    const iconSpan = crelt2("span", { class: styles2.explorerIcon }, "");
    const fileSpan = crelt2("span", { class: styles2.explorerFile }, node.name);
    const fileItem = crelt2("li", {
      "data-file": node.path,
      class: `${styles2.explorerItem} ${styles2.explorerFileItem}${node.path === selectedFile ? ` ${styles2.explorerItemSelected}` : ""}`,
      style: `padding-left: ${indentation}px`,
      onclick: () => {
        if (node.content) {
          debug3("Loading file:", node.path);
          const langExtension = getLanguageExtension(node.path);
          view.dispatch({
            effects: [
              selectFileEffect.of(node.path),
              ...langExtension ? [
                languageCompartment.reconfigure(langExtension)
              ] : []
            ],
            changes: {
              from: 0,
              to: view.state.doc.length,
              insert: node.content
            }
          });
        }
      }
    }, iconSpan, fileSpan);
    container.appendChild(fileItem);
  }
}
var fileExplorerPlugin = ViewPlugin2.fromClass(class {
  update(update) {
    if (update.state.field(fileExplorerState) !== update.startState.field(fileExplorerState)) {
      debug3("Explorer state changed, updating panel");
      const dom = update.view.dom.querySelector(`.${styles2.explorerContent}`);
      if (dom) {
        renderFileExplorer(dom, update.view);
      }
    }
  }
});
// src/explorer/commands.ts
function toggleExplorer(view) {
  return toggleSidebarCommand(view, "file-explorer");
}

// src/explorer/index.ts
var debug4 = (...args) => logger_default.debug("[Explorer]", ...args);
var explorerKeymap = Facet2.define({
  combine: (values) => values[0]
});
function setupPanelKeyboardShortcuts(dom, view, keyConfig) {
  const isMac = /Mac/.test(navigator.platform);
  const keys = typeof keyConfig === "string" ? { mac: keyConfig, win: keyConfig } : keyConfig;
  const targetKey = (isMac ? keys.mac : keys.win)?.toLowerCase();
  if (!targetKey)
    return;
  debug4("Setting up panel keyboard shortcuts:", { isMac, targetKey });
  dom.addEventListener("keydown", (event) => {
    const modKey = isMac ? event.metaKey : event.ctrlKey;
    if (!modKey)
      return;
    const pressedKey = `${isMac ? "cmd" : "ctrl"}-${event.key.toLowerCase()}`;
    debug4("Key pressed in panel:", pressedKey);
    if (pressedKey === targetKey) {
      event.preventDefault();
      event.stopPropagation();
      debug4("Executing panel keyboard shortcut:", targetKey);
      toggleSidebarCommand(view, "file-explorer");
    }
  });
}
function createFileSelectPlugin(onFileSelect) {
  return ViewPlugin3.fromClass(class {
    update(update) {
      if (!onFileSelect)
        return;
      for (const effect of update.transactions.flatMap((tr) => tr.effects)) {
        if (effect.is(selectFileEffect)) {
          onFileSelect(effect.value, update.view);
        }
      }
    }
  });
}
var explorerPanelSpec = {
  ...fileExplorerPanelSpec,
  create(view) {
    const dom = fileExplorerPanelSpec.create(view);
    const keymapOpt = view.state.facet(explorerKeymap);
    if (keymapOpt) {
      setupPanelKeyboardShortcuts(dom, view, keymapOpt);
    }
    return dom;
  }
};
function explorer(options = {}) {
  const {
    dock = defaultExplorerOptions.dock,
    width = defaultExplorerOptions.width,
    overlay = defaultExplorerOptions.overlay,
    backgroundColor = defaultExplorerOptions.backgroundColor,
    keymap: keymapOpt,
    initiallyOpen = defaultExplorerOptions.initiallyOpen,
    onFileSelect,
    theme = {}
  } = options;
  const sidebarOptions = {
    id: "file-explorer",
    dock,
    width,
    overlay,
    backgroundColor,
    initiallyOpen,
    initialPanelId: "file-explorer",
    theme
  };
  return [
    ...createSidebar(sidebarOptions),
    fileExplorerState,
    fileExplorerPlugin,
    sidebarPanel.of(explorerPanelSpec),
    languageCompartment.of([]),
    onFileSelect ? createFileSelectPlugin(onFileSelect) : [],
    keymapOpt ? explorerKeymap.of(keymapOpt) : [],
    createSidebarKeymap("file-explorer", keymapOpt),
    explorerTheme.theme
  ];
}
// src/assistant/index.ts
import { ViewPlugin as ViewPlugin4 } from "@codemirror/view";

// src/assistant/lib/state.ts
import { StateEffect as StateEffect3, StateField as StateField3 } from "@codemirror/state";
var switchTabEffect = StateEffect3.define();
var addMessageEffect = StateEffect3.define();
var updateMessageStatusEffect = StateEffect3.define();
var selectModelEffect = StateEffect3.define();
var setApiKeyEffect = StateEffect3.define();
var toggleSettingsEffect = StateEffect3.define();
var assistantState = StateField3.define({
  create() {
    const defaultModelId = "gpt-4";
    const savedApiKeys = localStorage.getItem("cm-ai-api-keys");
    const apiKeys = savedApiKeys ? JSON.parse(savedApiKeys) : {
      google: "",
      openai: "",
      mistral: ""
    };
    return {
      activeTab: "assistant",
      messages: [],
      isLoading: false,
      selectedModel: defaultModelId,
      apiKeys,
      showSettings: false
    };
  },
  update(value, tr) {
    for (const effect of tr.effects) {
      if (effect.is(switchTabEffect)) {
        return { ...value, activeTab: effect.value };
      } else if (effect.is(addMessageEffect)) {
        return {
          ...value,
          messages: [...value.messages, effect.value],
          isLoading: effect.value.status === "sending" || effect.value.status === "streaming"
        };
      } else if (effect.is(updateMessageStatusEffect)) {
        return {
          ...value,
          messages: value.messages.map((msg) => msg.id === effect.value.message.id ? {
            ...msg,
            status: effect.value.status,
            content: effect.value.content ?? msg.content
          } : msg),
          isLoading: effect.value.status === "sending" || effect.value.status === "streaming"
        };
      } else if (effect.is(selectModelEffect)) {
        return { ...value, selectedModel: effect.value };
      } else if (effect.is(setApiKeyEffect)) {
        const newState = {
          ...value,
          apiKeys: {
            ...value.apiKeys,
            [effect.value.provider]: effect.value.key
          }
        };
        localStorage.setItem("cm-ai-api-keys", JSON.stringify(newState.apiKeys));
        return newState;
      } else if (effect.is(toggleSettingsEffect)) {
        return { ...value, showSettings: effect.value };
      }
    }
    return value;
  }
});

// src/assistant/lib/renderer.ts
import crelt3 from "crelt";

// src/assistant/lib/codeblock.ts
import { StateField as StateField4, StateEffect as StateEffect4, EditorState } from "@codemirror/state";
import { EditorView as EditorView6, Decoration, WidgetType } from "@codemirror/view";
import { javascript as javascript2 } from "@codemirror/lang-javascript";
import { python as python2 } from "@codemirror/lang-python";
import { markdown as markdown2 } from "@codemirror/lang-markdown";
import { oneDark } from "@codemirror/theme-one-dark";
var getLanguageSupport = (lang) => {
  const normalizedLang = lang.toLowerCase().trim();
  switch (normalizedLang) {
    case "javascript":
    case "js":
      return javascript2();
    case "typescript":
    case "ts":
      return javascript2({ typescript: true });
    case "python":
    case "py":
      return python2();
    case "markdown":
    case "md":
      return markdown2();
    default:
      return null;
  }
};

class CodeBlockWidget extends WidgetType {
  code;
  language;
  isIncomplete;
  view = null;
  static chunkCounter = 0;
  constructor(code, language, isIncomplete = false) {
    super();
    this.code = code;
    this.language = language;
    this.isIncomplete = isIncomplete;
  }
  eq(other) {
    return this.code === other.code && this.language === other.language && this.isIncomplete === other.isIncomplete;
  }
  destroy() {
    this.view?.destroy();
  }
  toDOM() {
    const wrapper = document.createElement("div");
    wrapper.className = "cm-ext-assistant-code";
    if (this.language) {
      const header = document.createElement("div");
      header.className = "cm-ext-assistant-code-header";
      const dot = document.createElement("span");
      dot.textContent = "\u25CF";
      dot.style.marginRight = "6px";
      header.appendChild(dot);
      const langText = document.createElement("span");
      langText.textContent = this.language;
      header.appendChild(langText);
      if (this.isIncomplete) {
        CodeBlockWidget.chunkCounter = (CodeBlockWidget.chunkCounter + 1) % 3;
        const loadingDots = document.createElement("div");
        loadingDots.className = "cm-ext-assistant-loading-dots";
        for (let i = 0;i < 3; i++) {
          const dot2 = document.createElement("div");
          dot2.className = `cm-ext-assistant-loading-dot ${i <= CodeBlockWidget.chunkCounter ? "filled" : "empty"}`;
          loadingDots.appendChild(dot2);
        }
        header.appendChild(loadingDots);
      }
      if (!this.isIncomplete) {
        const copyButton = document.createElement("button");
        copyButton.className = "cm-ext-assistant-code-copy";
        copyButton.title = "Copy code";
        copyButton.innerHTML = `<svg width="14" height="14" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                    <rect x="9" y="9" width="13" height="13" rx="2" ry="2"></rect>
                    <path d="M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"></path>
                </svg>`;
        copyButton.addEventListener("click", async () => {
          try {
            await navigator.clipboard.writeText(this.code);
            const originalHTML = copyButton.innerHTML;
            copyButton.innerHTML = `<svg width="14" height="14" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                            <path d="M20 6L9 17l-5-5"></path>
                        </svg>`;
            setTimeout(() => {
              copyButton.innerHTML = originalHTML;
            }, 2000);
          } catch (err) {
            console.error("Failed to copy code:", err);
          }
        });
        header.appendChild(copyButton);
      }
      wrapper.appendChild(header);
    }
    if (!this.isIncomplete) {
      const editorContainer = document.createElement("div");
      editorContainer.className = "cm-ext-assistant-code-editor";
      const languageSupport = this.language ? getLanguageSupport(this.language) : null;
      const extensions = [
        EditorView6.editable.of(false),
        EditorView6.lineWrapping,
        EditorState.readOnly.of(true),
        oneDark
      ];
      if (languageSupport) {
        extensions.push(languageSupport);
      }
      this.view = new EditorView6({
        state: EditorState.create({
          doc: this.code,
          extensions
        }),
        parent: editorContainer
      });
      wrapper.appendChild(editorContainer);
    }
    return wrapper;
  }
}
var addCodeBlock = StateEffect4.define();
var removeCodeBlocks = StateEffect4.define();
var codeBlockState = StateField4.define({
  create() {
    return Decoration.none;
  },
  update(decorations, tr) {
    decorations = decorations.map(tr.changes);
    for (const effect of tr.effects) {
      if (effect.is(addCodeBlock)) {
        const { from, to, code, language } = effect.value;
        const widget = new CodeBlockWidget(code, language);
        const deco = Decoration.replace({
          widget,
          inclusive: true,
          block: true
        });
        decorations = decorations.update({
          add: [{ from, to, value: deco }],
          filter: (from2, to2) => from2 >= effect.value.to || to2 <= effect.value.from
        });
      } else if (effect.is(removeCodeBlocks)) {
        decorations = Decoration.none;
      }
    }
    return decorations;
  },
  provide: (f) => EditorView6.decorations.from(f)
});
var parseCodeBlocks = (text) => {
  const codeBlocks = [];
  const codeBlockRegex = /```([a-zA-Z]*)\n([\s\S]*?)\n```/g;
  let match;
  while ((match = codeBlockRegex.exec(text)) !== null) {
    codeBlocks.push({
      from: match.index,
      to: match.index + match[0].length,
      language: match[1] || null,
      code: match[2]
    });
  }
  return codeBlocks;
};

// src/ai/ai.ts
import { streamText } from "ai";
import { createOpenAI } from "@ai-sdk/openai";
import { createMistral } from "@ai-sdk/mistral";
import { createGoogleGenerativeAI } from "@ai-sdk/google";
var DEFAULT_MODEL = "openai:gpt-4o";
var debug5 = (...args) => logger_default.debug({ module: "AI" }, args.join(" "));
var createAIService = () => {
  const generateTextFn = async ({
    modelName,
    prompt,
    editorContent,
    apiKey,
    onTextContent
  }) => {
    if (!apiKey) {
      throw new Error("API key is required. Please configure it in settings.");
    }
    const fullPrompt = `Current Editor Content:
${editorContent}

${prompt}`;
    let result;
    let fullText = "";
    debug5("Generating text for model:", modelName);
    debug5("Prompt:", fullPrompt);
    try {
      const systemPrompt = "You are a helpful assistant that can help with coding tasks.";
      switch (modelName) {
        case "openai:gpt-4o": {
          const simulatedResponse = [
            `# Here's a simulated response with code examples

`,
            "## Let's start with a simple inline code example: ",
            "`console.log('hello world')`\n\n",
            "Here's a multiline code block:\n\n```jav",
            `ascript
function greet(name) {
`,
            "    console.log(`Hello, ${name}!`)\n    return {\n}\n",
            "    console.log(`Hello, ${name}!`)\n    return {\n",
            `        message: 'Greeting sent',
        timestamp: new Date()
    }
}

`,
            `// Example usage
const result = greet('Developer')
\`\`\`

`,
            "You can also use inline code for variables like `result` or ",
            `\`name\`.

Here's another code block with a different language:

`,
            "```python\ndef calculate_sum(numbers):\n    total = 0\n",
            `    for num in numbers:
        total += num
    return total

`,
            '# Test the function\nnumbers = [1, 2, 3, 4, 5]\nprint(f"Sum: {calculate_sum(numbers)}")\n```'
          ];
          result = {
            textStream: async function* () {
              for (const chunk of simulatedResponse) {
                await new Promise((resolve) => setTimeout(resolve, 400));
                yield chunk;
              }
            }()
          };
          break;
        }
        case "mistral:large": {
          const mistralClient = createMistral({
            apiKey
          });
          result = streamText({
            model: mistralClient("mistral-large-latest"),
            system: systemPrompt,
            prompt: fullPrompt
          });
          break;
        }
        case "google:gemini-2.0-flash-001": {
          const googleClient = createGoogleGenerativeAI({
            apiKey
          });
          result = streamText({
            model: googleClient("gemini-2.0-flash-001"),
            system: systemPrompt,
            prompt: fullPrompt
          });
          break;
        }
        default: {
          console.warn(`Unknown model: ${modelName}. Using default model.`);
          const openaiClient = createOpenAI({
            apiKey,
            compatibility: "strict"
          });
          result = streamText({
            model: openaiClient("gpt-4"),
            system: systemPrompt,
            prompt: fullPrompt
          });
        }
      }
      for await (const textPart of result.textStream) {
        fullText += textPart;
        onTextContent?.(fullText);
      }
      return fullText;
    } catch (error) {
      debug5("Error:", error);
      throw error;
    }
  };
  return {
    generateText: generateTextFn
  };
};
var aiService = createAIService();

// src/assistant/constants.ts
var AVAILABLE_MODELS = [
  {
    id: "gpt-4",
    provider: "openai",
    name: "GPT-4o",
    description: "OpenAI's most capable model"
  },
  {
    id: "gemini-pro",
    provider: "google",
    name: "Gemini Pro",
    description: "Google's most capable model for text generation"
  },
  {
    id: "mistral-large",
    provider: "mistral",
    name: "Mistral Large",
    description: "Mistral's largest open model"
  }
];

// src/assistant/lib/utils.ts
import { javascript as javascript3 } from "@codemirror/lang-javascript";
import { markdown as markdown3 } from "@codemirror/lang-markdown";
import { python as python3 } from "@codemirror/lang-python";
var mapModelToAIService = (modelId) => {
  switch (modelId) {
    case "gemini-pro":
      return "google:gemini-2.0-flash-001";
    case "gpt-4":
      return "openai:gpt-4o";
    case "mistral-large":
      return "mistral:large";
    default:
      return DEFAULT_MODEL;
  }
};
var formatProviderName = (provider) => {
  switch (provider) {
    case "openai":
      return "OpenAI";
    default:
      return provider.charAt(0).toUpperCase() + provider.slice(1);
  }
};

// src/assistant/lib/renderer.ts
var debug6 = (...args) => console.log("[Assistant Renderer]", ...args);
function renderAssistantPanel(dom, view) {
  const state = view.state.field(assistantState);
  if (!document.querySelector("#cm-spin-keyframes")) {
    const style = document.createElement("style");
    style.id = "cm-spin-keyframes";
    style.textContent = `
            @keyframes cm-spin {
                0% { transform: rotate(0deg); }
                100% { transform: rotate(360deg); }
            }
        `;
    document.head.appendChild(style);
  }
  if (state.showSettings) {
    renderSettingsPanel(dom, view);
    return;
  }
  dom.innerHTML = "";
  dom.className = "cm-ext-assistant-container";
  const tabsContainer = crelt3("div", { class: "cm-ext-assistant-tabs" });
  const tabsGroup = crelt3("div", { class: "cm-ext-assistant-tabs-group" });
  const assistantTab = crelt3("button", {
    class: "cm-ext-assistant-tab cm-ext-assistant-tab-active"
  }, "Assistant");
  tabsGroup.appendChild(assistantTab);
  const controlsContainer = crelt3("div", {
    class: "cm-ext-assistant-controls"
  });
  const modelSelect = crelt3("select", {
    class: "cm-ext-assistant-model-select"
  });
  AVAILABLE_MODELS.forEach((model) => {
    const option = crelt3("option", { value: model.id });
    option.textContent = model.name;
    option.style.direction = "ltr";
    option.style.textAlign = "right";
    if (model.id === state.selectedModel) {
      option.selected = true;
    }
    modelSelect.appendChild(option);
  });
  modelSelect.addEventListener("change", () => {
    view.dispatch({
      effects: selectModelEffect.of(modelSelect.value)
    });
  });
  const settingsButton = crelt3("button", { class: "cm-ext-assistant-settings-button" }, "\u2699\uFE0F");
  settingsButton.addEventListener("click", () => {
    debug6("Settings button clicked, dispatching toggleSettingsEffect(true)");
    debug6("State before dispatch:", view.state.field(assistantState));
    view.dispatch({
      effects: toggleSettingsEffect.of(true)
    });
    debug6("State after dispatch:", view.state.field(assistantState));
    debug6("showSettings value:", view.state.field(assistantState).showSettings);
  });
  controlsContainer.appendChild(modelSelect);
  controlsContainer.appendChild(settingsButton);
  tabsContainer.appendChild(tabsGroup);
  tabsContainer.appendChild(controlsContainer);
  dom.appendChild(tabsContainer);
  const messagesContainer = crelt3("div", {
    class: "cm-ext-assistant-messages"
  });
  const scrollToBottom = () => {
    requestAnimationFrame(() => {
      messagesContainer.scrollTop = messagesContainer.scrollHeight;
    });
  };
  state.messages.forEach((message) => {
    renderMessage(message, messagesContainer, scrollToBottom);
  });
  dom.appendChild(messagesContainer);
  const inputContainer = crelt3("div", { class: "cm-ext-assistant-input" });
  const textarea = crelt3("textarea", {
    placeholder: "Ask anything, @ to mention, \u2191 to select",
    rows: "3",
    onkeydown: async (e) => {
      if (e.key === "Enter" && !e.shiftKey) {
        e.preventDefault();
        const target = e.target;
        const content = target.value.trim();
        if (content) {
          debug6("Sending message:", content);
          const selectedModel = AVAILABLE_MODELS.find((m) => m.id === state.selectedModel);
          if (!selectedModel) {
            console.error("Selected model not found");
            return;
          }
          const apiKey = state.apiKeys[selectedModel.provider];
          if (!apiKey) {
            view.dispatch({
              effects: addMessageEffect.of({
                id: crypto.randomUUID(),
                role: "assistant",
                content: `Error: Please configure the API key for ${selectedModel.name} in settings.`,
                status: "complete"
              })
            });
            return;
          }
          target.value = "";
          const userMessage = {
            id: crypto.randomUUID(),
            role: "user",
            content,
            status: "complete"
          };
          view.dispatch({
            effects: addMessageEffect.of(userMessage)
          });
          const assistantMessage = {
            id: crypto.randomUUID(),
            role: "assistant",
            content: "",
            status: "streaming"
          };
          view.dispatch({
            effects: addMessageEffect.of(assistantMessage)
          });
          try {
            const editorContent = view.state.doc.toString();
            let streamedContent = "";
            const aiResponse = await aiService.generateText({
              modelName: mapModelToAIService(state.selectedModel),
              prompt: content,
              editorContent,
              apiKey,
              onTextContent: (text) => {
                streamedContent = text;
                view.dispatch({
                  effects: [
                    updateMessageStatusEffect.of({
                      message: assistantMessage,
                      status: "streaming",
                      content: text
                    })
                  ]
                });
                const messagesContainer2 = view.dom.querySelector(".cm-assistant-content")?.querySelector('div[style*="overflow-y: auto"]');
                if (messagesContainer2) {
                  messagesContainer2.scrollTop = messagesContainer2.scrollHeight;
                }
              }
            });
            view.dispatch({
              effects: [
                updateMessageStatusEffect.of({
                  message: assistantMessage,
                  status: "complete",
                  content: streamedContent || aiResponse
                })
              ]
            });
          } catch (error) {
            view.dispatch({
              effects: [
                updateMessageStatusEffect.of({
                  message: assistantMessage,
                  status: "complete",
                  content: `Error: ${error instanceof Error ? error.message : "An unknown error occurred"}`
                })
              ]
            });
          }
          requestIdleCallback(() => {
            const textareas = view.dom.getElementsByTagName("textarea");
            if (textareas.length > 0) {
              textareas[0].focus();
            }
          });
        }
      }
    }
  });
  inputContainer.appendChild(textarea);
  dom.appendChild(inputContainer);
}
function renderSettingsPanel(dom, view) {
  const state = view.state.field(assistantState);
  dom.innerHTML = "";
  dom.className = "cm-ext-assistant-settings";
  const headerContainer = crelt3("div", { class: "cm-ext-assistant-tabs" });
  const header = crelt3("div", { class: "cm-ext-assistant-tab cm-ext-assistant-tab-active" }, "API Key Settings");
  const backButton = crelt3("button", { class: "cm-ext-assistant-settings-button" }, "\u2190");
  backButton.addEventListener("click", () => {
    view.dispatch({
      effects: toggleSettingsEffect.of(false)
    });
    requestIdleCallback(() => {
      const textareas = view.dom.getElementsByTagName("textarea");
      if (textareas.length > 0) {
        textareas[0].focus();
      }
    });
  });
  headerContainer.appendChild(header);
  headerContainer.appendChild(backButton);
  dom.appendChild(headerContainer);
  const description = crelt3("div", { class: "cm-ext-assistant-settings-description" }, "Keys are stored locally and never transmitted");
  dom.appendChild(description);
  const inputsContainer = crelt3("div", {
    class: "cm-ext-assistant-settings-inputs"
  });
  AVAILABLE_MODELS.forEach((model) => {
    const container = crelt3("div", { class: "cm-ext-assistant-provider" });
    const label = crelt3("div", { class: "cm-ext-assistant-provider-header" }, formatProviderName(model.provider));
    container.appendChild(label);
    const messageContainer = crelt3("div", {
      class: "cm-ext-assistant-provider-message" + (state.apiKeys[model.provider] ? " has-api-key" : "")
    });
    if (state.apiKeys[model.provider]) {
      const checkmark = crelt3("span", { class: "checkmark" }, "\u2713");
      messageContainer.appendChild(checkmark);
      messageContainer.appendChild(document.createTextNode("API key configured."));
      const resetButton = crelt3("button", { class: "cm-ext-assistant-settings-button" }, "Reset key");
      resetButton.addEventListener("click", () => {
        input.value = "";
        view.dispatch({
          effects: setApiKeyEffect.of({
            provider: model.provider,
            key: ""
          })
        });
        messageContainer.classList.remove("has-api-key");
        inputGroup.classList.remove("has-api-key");
      });
      messageContainer.appendChild(resetButton);
    }
    const inputGroup = crelt3("div", {
      class: "cm-ext-assistant-provider-input" + (state.apiKeys[model.provider] ? " has-api-key" : "")
    });
    const input = crelt3("input", {
      type: "password",
      value: state.apiKeys[model.provider] || "",
      placeholder: model.provider === "google" ? "AIzaSy..." : model.provider === "openai" ? "sk-000000000000000000000000000000000000000000000000" : "ottggm..."
    });
    input.addEventListener("keydown", (e) => {
      if (e.key === "Enter") {
        input.blur();
      }
    });
    input.addEventListener("blur", () => {
      if (input.value) {
        view.dispatch({
          effects: setApiKeyEffect.of({
            provider: model.provider,
            key: input.value
          })
        });
      }
    });
    input.addEventListener("focus", () => {
      input.style.borderColor = "var(--cm-accent-color, #4a9eff)";
      input.style.boxShadow = "0 0 0 1px var(--cm-accent-color, #4a9eff)";
    });
    input.addEventListener("blur", () => {
      input.style.borderColor = "var(--cm-border-color, rgba(255, 255, 255, 0.1))";
      input.style.boxShadow = "none";
    });
    inputGroup.appendChild(input);
    container.appendChild(messageContainer);
    container.appendChild(inputGroup);
    inputsContainer.appendChild(container);
  });
  dom.appendChild(inputsContainer);
}
function renderMessage(message, container, scrollToBottom) {
  if (message.status === "streaming" && !message.content) {
    const loadingContainer = crelt3("div", {
      class: "cm-ext-assistant-loading"
    });
    const spinner = crelt3("div", { class: "cm-ext-assistant-spinner" });
    loadingContainer.appendChild(spinner);
    container.appendChild(loadingContainer);
  }
  if (message.content || message.status !== "streaming") {
    const messageEl = crelt3("div", {
      class: `cm-ext-assistant-message ${message.role === "user" ? "cm-ext-assistant-message-user" : "cm-ext-assistant-message-bot"}`
    });
    const contentEl = crelt3("div", {
      class: "cm-ext-assistant-message-content"
    });
    const codeBlocks = parseCodeBlocks(message.content);
    let lastPos = 0;
    const segments = [];
    codeBlocks.forEach((block) => {
      if (block.from > lastPos) {
        segments.push({
          type: "text",
          content: message.content.slice(lastPos, block.from)
        });
      }
      segments.push({
        type: "code",
        content: block.code,
        language: block.language
      });
      lastPos = block.to;
    });
    if (message.status === "streaming") {
      const remainingContent = message.content.slice(lastPos);
      const incompleteBlockMatch = /```([a-zA-Z]*)\n([\s\S]*)$/.exec(remainingContent);
      if (incompleteBlockMatch) {
        const incompleteBlockStart = remainingContent.lastIndexOf("```");
        if (incompleteBlockStart > 0) {
          segments.push({
            type: "text",
            content: remainingContent.slice(0, incompleteBlockStart)
          });
        }
        segments.push({
          type: "incomplete-code",
          content: "",
          language: incompleteBlockMatch[1] || null
        });
      } else {
        if (remainingContent) {
          segments.push({
            type: "text",
            content: remainingContent
          });
        }
      }
    } else {
      if (lastPos < message.content.length) {
        segments.push({
          type: "text",
          content: message.content.slice(lastPos)
        });
      }
    }
    segments.forEach((segment) => {
      if (segment.type === "code" || segment.type === "incomplete-code") {
        const codeBlockContainer = crelt3("div", {
          class: "cm-ext-assistant-code"
        });
        const widget = new CodeBlockWidget(segment.type === "code" ? segment.content : "", segment.language || null, segment.type === "incomplete-code");
        codeBlockContainer.appendChild(widget.toDOM());
        contentEl.appendChild(codeBlockContainer);
      } else if (segment.type === "text") {
        const textContainer = crelt3("div", {
          class: "cm-ext-assistant-text-container"
        });
        const inlineCodeRegex = /(?<!`)`([^`]+)`(?!`)/g;
        const processedText = segment.content.replace(inlineCodeRegex, (_, code) => `<code class="cm-ext-assistant-inline-code">${code}</code>`);
        textContainer.innerHTML = processedText;
        contentEl.appendChild(textContainer);
      }
    });
    messageEl.appendChild(contentEl);
    container.appendChild(messageEl);
    scrollToBottom();
  }
}

// src/assistant/index.ts
import { Facet as Facet3 } from "@codemirror/state";
var debug7 = (...args) => logger_default.debug("[Assistant]", ...args);
function setupPanelKeyboardShortcuts2(dom, view, keyConfig) {
  const isMac = /Mac/.test(navigator.platform);
  const keys = typeof keyConfig === "string" ? { mac: keyConfig, win: keyConfig } : keyConfig;
  const targetKey = (isMac ? keys.mac : keys.win)?.toLowerCase();
  if (!targetKey)
    return;
  debug7("Setting up panel keyboard shortcuts:", { isMac, targetKey });
  dom.addEventListener("keydown", (event) => {
    const modKey = isMac ? event.metaKey : event.ctrlKey;
    if (!modKey)
      return;
    const pressedKey = `${isMac ? "cmd" : "ctrl"}-${event.key.toLowerCase()}`;
    debug7("Key pressed in panel:", pressedKey);
    if (pressedKey === targetKey) {
      event.preventDefault();
      event.stopPropagation();
      debug7("Executing panel keyboard shortcut:", targetKey);
      toggleSidebarCommand(view, "ai-assistant");
    }
  });
}
var assistantPanelSpec = {
  id: "ai-assistant",
  create(view) {
    const dom = document.createElement("div");
    dom.className = "cm-assistant-content";
    renderAssistantPanel(dom, view);
    const keymapOpt = view.state.facet(assistantKeymap);
    if (keymapOpt) {
      setupPanelKeyboardShortcuts2(dom, view, keymapOpt);
    }
    return dom;
  },
  update(view) {
    const dom = view.dom.querySelector(".cm-assistant-content");
    if (dom) {
      renderAssistantPanel(dom, view);
    }
  },
  onVisibilityChange(view, visible) {
    const root = view.dom;
    if (visible) {
      const panel = view.dom.querySelector('.cm-sidebar-panel-container[data-dock="right"]');
      const width = panel ? panel.style.width || "400px" : "400px";
      root.style.setProperty("--assistant-width", width);
      requestIdleCallback(() => {
        const textareas = view.dom.getElementsByTagName("textarea");
        if (textareas.length > 0) {
          textareas[0].focus();
        }
      });
    } else {
      root.style.setProperty("--assistant-width", "0px");
    }
  }
};
var assistantKeymap = Facet3.define({
  combine: (values) => values[0]
});
var assistantPlugin = ViewPlugin4.fromClass(class {
  update(update) {
    if (update.state.field(assistantState) !== update.startState.field(assistantState)) {
      const dom = update.view.dom.querySelector(".cm-ext-assistant-container, .cm-ext-assistant-settings");
      if (dom) {
        renderAssistantPanel(dom, update.view);
      }
    }
  }
});
function assistant(options = {}) {
  const {
    keymap: keymapOpt,
    initiallyOpen = false,
    ...sidebarOptions
  } = options;
  return [
    ...createSidebar({
      ...sidebarOptions,
      id: "ai-assistant",
      dock: "right",
      overlay: true,
      initiallyOpen,
      initialPanelId: "ai-assistant"
    }),
    assistantState,
    sidebarPanel.of(assistantPanelSpec),
    assistantPlugin,
    keymapOpt ? assistantKeymap.of(keymapOpt) : [],
    createSidebarKeymap("ai-assistant", keymapOpt)
  ];
}
// src/hooks/index.ts
import { useEffect, useRef } from "react";
import { EditorState as EditorState2 } from "@codemirror/state";
import { EditorView as EditorView9 } from "@codemirror/view";
import { javascript as javascript4 } from "@codemirror/lang-javascript";
import { oneDark as oneDark2 } from "@codemirror/theme-one-dark";
import { basicSetup } from "codemirror";

// src/themes/base.ts
import { EditorView as EditorView7 } from "@codemirror/view";
var baseTheme = EditorView7.theme({
  "&": {
    height: "100vh",
    display: "flex !important",
    flexDirection: "row !important",
    position: "relative"
  },
  ".cm-scroller": {
    background: "var(--cm-editor-background, #23272d)",
    overflowY: "scroll",
    overflowX: "auto",
    flex: "1 1 auto !important",
    minWidth: "0 !important",
    position: "relative",
    marginRight: "var(--assistant-width, 0px)",
    "&::-webkit-scrollbar": {
      width: "20px",
      height: "14px"
    },
    "&::-webkit-scrollbar-track": {
      background: "var(--cm-scrollbar-track, rgba(35, 39, 45, 1))"
    },
    "&::-webkit-scrollbar-thumb": {
      background: "var(--cm-scrollbar-thumb, rgba(69, 74, 81, 0.5))",
      borderRadius: "0",
      border: "3px solid var(--cm-editor-background, #23272d)"
    },
    "&::-webkit-scrollbar-thumb:hover": {
      background: "var(--cm-scrollbar-thumb-hover, #555b63)"
    },
    "&:after": {
      content: '""',
      position: "absolute",
      top: 0,
      height: "calc(100% + 20%)",
      width: "1px",
      visibility: "hidden"
    }
  },
  ".cm-content": {
    minHeight: "100%",
    caretColor: "var(--cm-caret-color, #fff)",
    fontFamily: "var(--cm-font-family, monospace)"
  },
  ".cm-gutter": {
    background: "var(--cm-gutter-background, #23272d)",
    width: "30px",
    color: "var(--cm-gutter-color, #636363)"
  }
});
var sidebarBaseTheme = EditorView7.theme({
  ".cm-sidebar-panel-container": {
    background: "var(--cm-sidebar-background, #1e2227)",
    color: "var(--cm-sidebar-text, #b1b1b3)"
  },
  '.cm-sidebar-panel-container[data-dock="left"]': {
    borderRight: "var(--cm-sidebar-border, 0.5px solid rgba(255, 255, 255, 0.2))"
  },
  '.cm-sidebar-panel-container[data-dock="right"]': {
    borderLeft: "var(--cm-sidebar-border, 0.5px solid rgba(255, 255, 255, 0.2))"
  },
  ".cm-sidebar-resize-handle": {
    cursor: "col-resize",
    transition: "none",
    backgroundColor: "transparent",
    "&:hover": {
      backgroundColor: "var(--cm-resize-handle-hover, rgba(255, 255, 255, 0.1))",
      transitionProperty: "background-color",
      transitionDuration: "0.2s",
      transitionTimingFunction: "ease",
      transitionDelay: "150ms"
    },
    "&:active": {
      backgroundColor: "var(--cm-resize-handle-active, rgba(255, 255, 255, 0.1))",
      transition: "none"
    }
  }
});
function createTheme(variables) {
  return EditorView7.theme({
    "&": Object.entries(variables).reduce((acc, [key, value]) => ({
      ...acc,
      [key]: value
    }), {})
  });
}
// src/themes/assistant.ts
import { EditorView as EditorView8 } from "@codemirror/view";
var assistantThemeVariables = {
  "--cm-ext-assistant-text": "#e1e1e3",
  "--cm-ext-assistant-text-secondary": "rgba(255, 255, 255, 0.6)",
  "--cm-ext-assistant-border": "rgba(255, 255, 255, 0.1)",
  "--cm-ext-assistant-bg-input": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-assistant-bg-message": "rgba(255, 255, 255, 0.05)",
  "--cm-ext-assistant-bg-selected": "rgba(255, 255, 255, 0.03)",
  "--cm-ext-assistant-accent": "rgba(74, 158, 255, 0.2)",
  "--cm-ext-assistant-bg-code": "#1e1e1e",
  "--cm-ext-assistant-border-focus": "rgba(255, 255, 255, 0.3)",
  "--cm-ext-assistant-font": "system-ui, -apple-system, sans-serif",
  "--cm-ext-assistant-font-mono": "ui-monospace, SFMono-Regular, SF Mono, Menlo, Consolas, Liberation Mono, monospace",
  "--cm-ext-assistant-font-size": "13px",
  "--cm-ext-assistant-line-height": "1.4",
  "--cm-ext-assistant-font-size-header": "13px",
  "--cm-ext-assistant-font-weight-header": "500",
  "--cm-ext-assistant-font-size-message": "13px"
};
var assistantTheme = {
  theme: EditorView8.theme({
    "&": {
      ...Object.entries(assistantThemeVariables).reduce((acc, [key, value]) => ({
        ...acc,
        [key]: value
      }), {})
    },
    ".cm-ext-assistant-container": {
      display: "flex",
      flexDirection: "column",
      height: "100%",
      overflow: "hidden",
      boxSizing: "border-box",
      padding: "12px 12px 6px 12px",
      color: "var(--cm-ext-assistant-text)",
      fontFamily: "var(--cm-ext-assistant-font)",
      fontSize: "var(--cm-ext-assistant-font-size)",
      lineHeight: "var(--cm-ext-assistant-line-height)"
    },
    ".cm-ext-assistant-tabs": {
      display: "flex",
      justifyContent: "space-between",
      alignItems: "flex-end",
      height: "36px",
      borderBottom: "1px solid var(--cm-ext-assistant-border)"
    },
    ".cm-ext-assistant-tab": {
      background: "none",
      border: "none",
      padding: "8px 10px",
      height: "35px",
      fontSize: "var(--cm-ext-assistant-font-size)",
      fontWeight: "500",
      cursor: "pointer",
      borderRadius: "4px 4px 0 0",
      color: "var(--cm-ext-assistant-text)",
      opacity: "0.7",
      transition: "opacity 0.2s",
      position: "relative",
      boxSizing: "border-box",
      "&.cm-ext-assistant-tab-active": {
        background: "var(--cm-ext-assistant-bg-selected)",
        opacity: "1",
        "&::after": {
          content: '""',
          position: "absolute",
          bottom: "-1px",
          left: 0,
          right: 0,
          height: "1px",
          background: "var(--cm-ext-assistant-bg-selected)"
        }
      }
    },
    ".cm-ext-assistant-messages": {
      flex: "1",
      overflowY: "auto",
      padding: "8px 0",
      display: "flex",
      flexDirection: "column",
      gap: "8px"
    },
    ".cm-ext-assistant-message": {
      maxWidth: "85%",
      padding: "8px 10px",
      borderRadius: "12px",
      fontSize: "var(--cm-ext-assistant-font-size-message)",
      display: "flex",
      flexDirection: "column",
      gap: "4px",
      "&.cm-ext-assistant-message-user": {
        alignSelf: "flex-end",
        background: "var(--cm-ext-assistant-accent)",
        color: "var(--cm-ext-assistant-text)"
      },
      "&.cm-ext-assistant-message-bot": {
        alignSelf: "flex-start",
        width: "98%",
        maxWidth: "98%",
        background: "var(--cm-ext-assistant-bg-message)",
        color: "var(--cm-ext-assistant-text)"
      }
    },
    ".cm-ext-assistant-message-content": {
      whiteSpace: "pre-wrap",
      lineHeight: "1.2",
      display: "flex",
      flexDirection: "column",
      gap: "0",
      width: "100%",
      boxSizing: "border-box"
    },
    ".cm-ext-assistant-code": {
      margin: "0",
      position: "relative",
      border: "1px solid var(--cm-ext-assistant-border)",
      borderRadius: "8px",
      overflow: "hidden",
      backgroundColor: "var(--cm-ext-assistant-bg-code)",
      boxShadow: "0 2px 4px rgba(0, 0, 0, 0.05)"
    },
    ".cm-ext-assistant-code-header": {
      padding: "8px 12px",
      borderBottom: "1px solid var(--cm-ext-assistant-border)",
      background: "linear-gradient(to bottom, rgba(255, 255, 255, 0.08), rgba(255, 255, 255, 0.05))",
      color: "var(--cm-ext-assistant-text-secondary)",
      fontSize: "11px",
      fontFamily: "var(--cm-ext-assistant-font-mono)",
      textTransform: "lowercase",
      letterSpacing: "0.5px",
      display: "flex",
      alignItems: "center",
      gap: "6px",
      userSelect: "none",
      height: "37px",
      boxSizing: "border-box"
    },
    ".cm-ext-assistant-input": {
      borderTop: "1px solid var(--cm-ext-assistant-border)",
      padding: "12px 12px 6px 12px",
      width: "100%",
      boxSizing: "border-box",
      "& textarea": {
        width: "100%",
        boxSizing: "border-box",
        background: "var(--cm-ext-assistant-bg-input)",
        border: "1px solid var(--cm-ext-assistant-border)",
        borderRadius: "4px",
        color: "var(--cm-ext-assistant-text)",
        padding: "8px 12px",
        fontSize: "var(--cm-ext-assistant-font-size)",
        lineHeight: "var(--cm-ext-assistant-line-height)",
        resize: "none",
        outline: "none",
        transition: "border-color 0.2s ease",
        "&:focus": {
          borderColor: "var(--cm-ext-assistant-border-focus)"
        }
      }
    },
    ".cm-ext-assistant-settings": {
      display: "flex",
      flexDirection: "column",
      height: "100%",
      overflow: "hidden",
      boxSizing: "border-box",
      padding: "12px 12px 6px 12px"
    },
    ".cm-ext-assistant-settings-description": {
      fontSize: "12px",
      marginTop: "12px",
      marginBottom: "16px",
      color: "var(--cm-text-color, #e1e1e3)",
      opacity: "0.7"
    },
    ".cm-ext-assistant-settings-inputs": {
      display: "flex",
      flexDirection: "column",
      gap: "24px"
    },
    ".cm-ext-assistant-settings-input": {
      display: "flex",
      gap: "8px",
      padding: "8px",
      borderRadius: "6px",
      height: "49px",
      boxSizing: "border-box",
      "& input": {
        flex: "1",
        background: "var(--cm-input-bg, rgba(0, 0, 0, 0.2))",
        border: "1px solid var(--cm-border-color, rgba(255, 255, 255, 0.1))",
        borderRadius: "4px",
        padding: "8px 12px",
        fontSize: "13px",
        color: "var(--cm-text-color, #e1e1e3)",
        outline: "none",
        transition: "all 0.2s ease",
        fontFamily: "monospace",
        boxSizing: "border-box"
      }
    },
    ".cm-ext-assistant-controls": {
      display: "flex",
      alignItems: "center",
      gap: "8px"
    },
    ".cm-ext-assistant-model-select": {
      background: "transparent",
      border: "transparent",
      borderRadius: "4px",
      color: "var(--cm-ext-assistant-text)",
      padding: "4px 24px 4px 8px",
      fontSize: "var(--cm-ext-assistant-font-size)",
      cursor: "pointer",
      outline: "none",
      appearance: "none",
      backgroundImage: 'url("data:image/svg+xml;charset=US-ASCII,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%2214%22%20height%3D%2214%22%20viewBox%3D%220%200%2014%2014%22%3E%3Cpath%20fill%3D%22%23e1e1e3%22%20d%3D%22M7%2010L3.5%206h7L7%2010z%22%2F%3E%3C%2Fsvg%3E")',
      backgroundRepeat: "no-repeat",
      backgroundPosition: "right 4px center",
      textAlign: "right",
      direction: "rtl"
    },
    ".cm-ext-assistant-loading": {
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      padding: "4px 0",
      alignSelf: "flex-start",
      opacity: "0.7"
    },
    ".cm-ext-assistant-spinner": {
      width: "12px",
      height: "12px",
      border: "1.5px solid var(--cm-ext-assistant-border)",
      borderTop: "1.5px solid var(--cm-ext-assistant-text)",
      borderRadius: "50%",
      animation: "cm-spin 0.8s linear infinite"
    },
    ".cm-ext-assistant-header-spinner": {
      marginLeft: "auto",
      width: "8px",
      height: "8px",
      border: "1.5px solid transparent",
      borderTopColor: "currentColor",
      borderRightColor: "currentColor",
      borderRadius: "50%",
      animation: "cm-spin 0.8s linear infinite"
    },
    ".cm-ext-assistant-code-copy": {
      background: "none",
      border: "none",
      padding: "4px",
      cursor: "pointer",
      color: "inherit",
      opacity: "0.5",
      transition: "opacity 0.2s",
      marginLeft: "auto",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      height: "16px",
      "&:hover": {
        opacity: "0.8"
      }
    },
    ".cm-ext-assistant-code-incomplete": {
      padding: "16px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      minHeight: "60px",
      color: "var(--cm-ext-assistant-text-secondary)",
      fontFamily: "var(--cm-ext-assistant-font-mono)",
      fontSize: "var(--cm-ext-assistant-font-size)",
      background: "var(--cm-ext-assistant-bg-code)",
      borderTop: "1px solid var(--cm-ext-assistant-border)"
    },
    ".cm-ext-assistant-inline-code": {
      background: "var(--cm-ext-assistant-bg-code)",
      padding: "1px 4px",
      borderRadius: "3px",
      fontFamily: "var(--cm-ext-assistant-font-mono)",
      fontSize: "calc(var(--cm-ext-assistant-font-size) - 1px)",
      display: "inline",
      whiteSpace: "pre",
      color: "var(--cm-ext-assistant-text)"
    },
    ".cm-ext-assistant-loading-dots": {
      display: "inline-flex",
      alignItems: "center",
      gap: "3px",
      marginLeft: "auto",
      opacity: "0.5",
      height: "16px"
    },
    ".cm-ext-assistant-loading-dot": {
      width: "3px",
      height: "3px",
      borderRadius: "50%",
      transition: "background-color 0.15s ease",
      "&.filled": {
        backgroundColor: "currentColor"
      },
      "&.empty": {
        backgroundColor: "var(--cm-ext-assistant-border)"
      }
    },
    ".cm-ext-assistant-provider": {
      display: "flex",
      flexDirection: "column",
      gap: "2px",
      padding: "2px",
      background: "var(--cm-input-bg, rgba(255, 255, 255, 0.03))",
      borderRadius: "4px"
    },
    ".cm-ext-assistant-provider-header": {
      fontSize: "13px",
      fontWeight: "600",
      color: "var(--cm-text-color, #e1e1e3)",
      padding: "8px 12px",
      display: "flex",
      justifyContent: "space-between",
      alignItems: "center",
      width: "100%",
      boxSizing: "border-box"
    },
    ".cm-ext-assistant-provider-message": {
      fontSize: "13px",
      color: "var(--cm-text-color, #e1e1e3)",
      opacity: "0.8",
      padding: "4px 12px",
      display: "none",
      alignItems: "center",
      borderRadius: "4px",
      height: "49px",
      boxSizing: "border-box",
      gap: "8px",
      "&.has-api-key": {
        display: "flex"
      },
      "& .checkmark": {
        color: "#4caf50"
      },
      "& .cm-ext-assistant-settings-button": {
        marginLeft: "auto",
        padding: "8px",
        height: "100%",
        alignSelf: "center",
        opacity: "0.5",
        "&:hover": {
          opacity: "0.8"
        }
      }
    },
    ".cm-ext-assistant-provider-input": {
      display: "flex",
      gap: "8px",
      padding: "8px",
      borderRadius: "6px",
      height: "49px",
      boxSizing: "border-box",
      "&.has-api-key": {
        display: "none"
      },
      "& input": {
        flex: "1",
        background: "var(--cm-input-bg, rgba(0, 0, 0, 0.2))",
        border: "1px solid var(--cm-border-color, rgba(255, 255, 255, 0.1))",
        borderRadius: "4px",
        padding: "8px 12px",
        fontSize: "13px",
        color: "var(--cm-text-color, #e1e1e3)",
        outline: "none",
        transition: "all 0.2s ease",
        fontFamily: "monospace",
        boxSizing: "border-box"
      }
    },
    "@keyframes cm-spin": {
      from: { transform: "rotate(0deg)" },
      to: { transform: "rotate(360deg)" }
    },
    ".cm-ext-assistant-settings-button": {
      background: "none",
      border: "none",
      padding: "6px 8px",
      fontSize: "var(--cm-ext-assistant-font-size)",
      cursor: "pointer",
      opacity: "0.7",
      transition: "opacity 0.2s",
      color: "var(--cm-ext-assistant-text)",
      display: "flex",
      alignItems: "center",
      "&:hover": {
        opacity: "1"
      },
      ".cm-ext-assistant-provider-input &": {
        marginLeft: "8px",
        padding: "8px",
        height: "100%",
        alignSelf: "center",
        opacity: "0.5",
        "&:hover": {
          opacity: "0.8"
        }
      }
    },
    ".cm-ext-assistant-tabs-group": {
      display: "flex",
      alignItems: "center",
      gap: "4px"
    },
    ".cm-ext-assistant-code-editor": {
      backgroundColor: "transparent !important",
      height: "auto !important",
      flex: "initial !important",
      position: "static !important"
    },
    ".cm-ext-assistant-code-editor .cm-content": {
      padding: "16px !important",
      height: "auto !important",
      fontFamily: "var(--cm-ext-assistant-font-mono) !important",
      fontSize: "var(--cm-ext-assistant-font-size) !important",
      lineHeight: "1.5 !important"
    },
    ".cm-ext-assistant-code-editor .cm-line": {
      padding: "0 !important"
    },
    ".cm-ext-assistant-code-editor .cm-scroller": {
      height: "auto !important",
      flex: "initial !important",
      width: "100% !important"
    }
  })
};
// src/themes/index.ts
function createCompleteTheme(options) {
  const { dark = true, variables = {} } = options;
  return [
    baseTheme,
    sidebarBaseTheme,
    explorerTheme.theme,
    dark && explorerTheme.darkTheme,
    !dark && explorerTheme.lightTheme,
    assistantTheme.theme,
    dark && assistantTheme.darkTheme,
    !dark && assistantTheme.lightTheme,
    createTheme(variables)
  ].filter(Boolean);
}

// src/hooks/index.ts
function useEditor(config = {}) {
  const editorRef = useRef(null);
  const viewRef = useRef(null);
  useEffect(() => {
    if (!editorRef.current)
      return;
    const {
      initialContent = "",
      explorer: explorerConfig,
      assistant: assistantConfig,
      extensions = [],
      theme = { dark: true }
    } = config;
    const state = EditorState2.create({
      doc: initialContent,
      extensions: [
        basicSetup,
        javascript4(),
        oneDark2,
        ...explorerConfig ? [
          explorer({
            dock: "left",
            width: "250px",
            overlay: false,
            backgroundColor: "#2c313a",
            initiallyOpen: false,
            projectName: explorerConfig.projectName,
            ...explorerConfig
          })
        ] : [],
        ...assistantConfig ? [
          assistant({
            width: "400px",
            backgroundColor: "#2c313a",
            initiallyOpen: false,
            ...assistantConfig
          })
        ] : [],
        ...extensions,
        ...createCompleteTheme(theme)
      ]
    });
    const view = new EditorView9({
      state,
      parent: editorRef.current
    });
    if (explorerConfig?.initialFiles) {
      view.dispatch({
        effects: updateFilesEffect.of(explorerConfig.initialFiles)
      });
    }
    if (explorerConfig?.projectName) {
      view.dispatch({
        effects: setProjectNameEffect.of(explorerConfig.projectName)
      });
    }
    view.focus();
    viewRef.current = view;
    return () => {
      view.destroy();
      viewRef.current = null;
    };
  }, [config]);
  const updateProjectName = (projectName) => {
    if (!viewRef.current)
      return;
    viewRef.current.dispatch({
      effects: setProjectNameEffect.of(projectName)
    });
  };
  return {
    ref: editorRef,
    view: viewRef.current,
    updateProjectName
  };
}
export {
  useEditor
};
